%macro fcf_iem_close_dimension_rels;

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002OT * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    HOUSEHOLD_PARTY_CLOSE -               A5DG55RP.BH0001AD * 
 *                   iem.HOUSEHOLD_PARTY_CLOSE                              * 
 * Target Table:    Extract - work.W1H0Z727               A5DG55RP.BR0001RW * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.HOUSEHOLD_PARTY_CLOSE); 

/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H0Z727;
quit;

proc sql;
   create view work.W1H0Z727 as
      select
         party_key   
            format = 13.
            informat = 13.,
         household_key   
            format = 13.
            informat = 13.
   from &SOURCEDS
      where CHANGE_CURRENT_IND = "Y"  & SEGMENT_ID = "&segKCSchema"
   ;
quit;

%let SOURCEDS = work.W1H0Z727;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002OU * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Extract - work.W1H0Z727               A5DG55RP.BR0001RW * 
 *                  FSC_HOUSEHOLD_DIM -                   A5DG55RP.BH00019C * 
 *                   &db_core_libname..FSC_HOUSEHOLD_DIM                              * 
 *                  FSC_PARTY_DIM - &db_core_libname..FSC_PARTY_DIM A5DG55RP.BH00019F * 
 * Target Table:    Lookup - work.WPG8GGA2                A5DG55RP.BR0001RX * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete WPG8GGA2;
quit;

DATA  work.WPG8GGA2
         (keep = HOUSEHOLD_NUMBER PARTY_NUMBER )
      ; 
   
   attrib HOUSEHOLD_NUMBER length=$50 format=$50. label="HOUSEHOLD_NUMBER"
          PARTY_NUMBER length=$50 format=$50. label="PARTY_NUMBER"
          HOUSEHOLD_KEY length= 8
          PARTY_KEY length= 8
          ; 
   
   retain missing0-missing1 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table &db_core_libname..FSC_HOUSEHOLD_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_HOUSEHOLD_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "&db_core_libname..FSC_HOUSEHOLD_DIM", hashexp: exponent);
            h0.defineKey( "HOUSEHOLD_KEY");
            h0.defineData( "HOUSEHOLD_NUMBER");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_HOUSEHOLD_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_HOUSEHOLD_DIM";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_HOUSEHOLD_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_HOUSEHOLD_DIM";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_HOUSEHOLD_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_HOUSEHOLD_DIM";
         
         abort 3; 
      end; 
      
      /* Build hash h1 from lookup table &db_core_libname..FSC_PARTY_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_PARTY_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h1(dataset: "&db_core_libname..FSC_PARTY_DIM", hashexp: exponent);
            h1.defineKey( "PARTY_KEY");
            h1.defineData( "PARTY_NUMBER");
            h1.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h1.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_PARTY_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_PARTY_DIM";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_PARTY_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_PARTY_DIM";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_PARTY_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_PARTY_DIM";
         
         abort 3; 
      end; 
      
      call missing (HOUSEHOLD_KEY, HOUSEHOLD_NUMBER, PARTY_KEY, PARTY_NUMBER); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W1H0Z727 end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: household_key);
   /* Is the current key value stored in hash h1?  */ 
   rc1 = h1.find(key: party_key);
   /* Examine success of lookups  */ 
   if ( rc0=0 and rc1=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.WPG8GGA2; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (HOUSEHOLD_NUMBER); 
         etls_assign_target_value = 1; 
      end; 
      
      if (rc1 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (PARTY_NUMBER); 
         etls_assign_target_value = 1; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.WPG8GGA2; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002OV * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    HOUSEHOLD_ACCOUNT_CLOSE -             A5DG55RP.BH0001AA * 
 *                   iem.HOUSEHOLD_ACCOUNT_NEW                              * 
 * Target Table:    Extract - work.W1H0ZTSA               A5DG55RP.BR0001RY * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.HOUSEHOLD_ACCOUNT_NEW); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H0ZTSA;
quit;

proc sql;
   create view work.W1H0ZTSA as
      select
         household_key   
            format = 13.
            informat = 13.,
         account_key   
            format = 13.
            informat = 13.
   from &SOURCEDS
      where CHANGE_CURRENT_IND = "Y" & SEGMENT_ID = "&segKCSchema"
   ;
quit;

%let SOURCEDS = work.W1H0ZTSA;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002OW * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Extract - work.W1H0ZTSA               A5DG55RP.BR0001RY * 
 *                  FSC_HOUSEHOLD_DIM -                   A5DG55RP.BH00019C * 
 *                   &db_core_libname..FSC_HOUSEHOLD_DIM                              * 
 *                  FSC_ACCOUNT_DIM -                     A5DG55RP.BH000198 * 
 *                   &db_core_libname..FSC_ACCOUNT_DIM                                * 
 * Target Table:    Lookup - work.WPG8I50R                A5DG55RP.BR0001RZ * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete WPG8I50R;
quit;

DATA  work.WPG8I50R
         (keep = HOUSEHOLD_NUMBER ACCOUNT_NUMBER )
      ; 
   
   attrib HOUSEHOLD_NUMBER length=$50 format=$50. label="HOUSEHOLD_NUMBER"
          ACCOUNT_NUMBER length=$50 format=$50. label="ACCOUNT_NUMBER"
          HOUSEHOLD_KEY length= 8
          ACCOUNT_KEY length= 8
          ; 
   
   retain missing0-missing1 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table &db_core_libname..FSC_HOUSEHOLD_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_HOUSEHOLD_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "&db_core_libname..FSC_HOUSEHOLD_DIM", hashexp: exponent);
            h0.defineKey( "HOUSEHOLD_KEY");
            h0.defineData( "HOUSEHOLD_NUMBER");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_HOUSEHOLD_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_HOUSEHOLD_DIM";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_HOUSEHOLD_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_HOUSEHOLD_DIM";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_HOUSEHOLD_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_HOUSEHOLD_DIM";
         
         abort 3; 
      end; 
      
      /* Build hash h1 from lookup table &db_core_libname..FSC_ACCOUNT_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_ACCOUNT_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h1(dataset: "&db_core_libname..FSC_ACCOUNT_DIM", hashexp: exponent);
            h1.defineKey( "ACCOUNT_KEY");
            h1.defineData( "ACCOUNT_NUMBER");
            h1.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h1.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_ACCOUNT_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_ACCOUNT_DIM";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_ACCOUNT_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_ACCOUNT_DIM";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_ACCOUNT_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_ACCOUNT_DIM";
         
         abort 3; 
      end; 
      
      call missing (HOUSEHOLD_KEY, HOUSEHOLD_NUMBER, ACCOUNT_KEY, ACCOUNT_NUMBER); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W1H0ZTSA end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: household_key);
   /* Is the current key value stored in hash h1?  */ 
   rc1 = h1.find(key: account_key);
   /* Examine success of lookups  */ 
   if ( rc0=0 and rc1=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.WPG8I50R; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (HOUSEHOLD_NUMBER); 
         etls_assign_target_value = 1; 
      end; 
      
      if (rc1 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (ACCOUNT_NUMBER); 
         etls_assign_target_value = 1; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.WPG8I50R; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002OX * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    PARTY_ACCOUNT_CLOSE -                 A5DG55RP.BH0001AH * 
 *                   iem.PARTY_ACCOUNT_NEW                                  * 
 * Target Table:    Extract - work.W1H10ELN               A5DG55RP.BR0001S0 * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.PARTY_ACCOUNT_NEW); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H10ELN;
quit;

proc sql;
   create view work.W1H10ELN as
      select
         account_key   
            format = 13.
            informat = 13.,
         party_key   
            format = 13.
            informat = 13.
   from &SOURCEDS
      where CHANGE_CURRENT_IND = "Y" & SEGMENT_ID = "&segKCSchema"
   ;
quit;

%let SOURCEDS = work.W1H10ELN;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002OY * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Extract - work.W1H10ELN               A5DG55RP.BR0001S0 * 
 *                  FSC_PARTY_DIM - &db_core_libname..FSC_PARTY_DIM A5DG55RP.BH00019F * 
 *                  FSC_ACCOUNT_DIM -                     A5DG55RP.BH000198 * 
 *                   &db_core_libname..FSC_ACCOUNT_DIM                                * 
 * Target Table:    Lookup - work.WPG8IV29                A5DG55RP.BR0001S1 * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete WPG8IV29;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.WPG8IV29
         (keep = PARTY_NUMBER ACCOUNT_NUMBER )
      ; 
   
   attrib PARTY_NUMBER length=$50 format=$50. label="PARTY_NUMBER"
          ACCOUNT_NUMBER length=$50 format=$50. label="ACCOUNT_NUMBER"
          PARTY_KEY length= 8
          ACCOUNT_KEY length= 8
          ; 
   
   retain missing0-missing1 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table &db_core_libname..FSC_PARTY_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_PARTY_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "&db_core_libname..FSC_PARTY_DIM", hashexp: exponent);
            h0.defineKey( "PARTY_KEY");
            h0.defineData( "PARTY_NUMBER");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_PARTY_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_PARTY_DIM";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_PARTY_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_PARTY_DIM";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_PARTY_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_PARTY_DIM";
         
         abort 3; 
      end; 
      
      /* Build hash h1 from lookup table &db_core_libname..FSC_ACCOUNT_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_ACCOUNT_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h1(dataset: "&db_core_libname..FSC_ACCOUNT_DIM", hashexp: exponent);
            h1.defineKey( "ACCOUNT_KEY");
            h1.defineData( "ACCOUNT_NUMBER");
            h1.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h1.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_ACCOUNT_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_ACCOUNT_DIM";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_ACCOUNT_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_ACCOUNT_DIM";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_ACCOUNT_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_ACCOUNT_DIM";
         
         abort 3; 
      end; 
      
      call missing (PARTY_KEY, PARTY_NUMBER, ACCOUNT_KEY, ACCOUNT_NUMBER); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W1H10ELN end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: party_key);
   /* Is the current key value stored in hash h1?  */ 
   rc1 = h1.find(key: account_key);
   /* Examine success of lookups  */ 
   if ( rc0=0 and rc1=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.WPG8IV29; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (PARTY_NUMBER); 
         etls_assign_target_value = 1; 
      end; 
      
      if (rc1 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (ACCOUNT_NUMBER); 
         etls_assign_target_value = 1; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.WPG8IV29; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002OZ * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 * Target Table:    Extract - work.W1H68XOB               A5DG55RP.BR0001S2 * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(ecm_db.PARTY_LIVE); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H68XOB;
quit;

proc sql;
   create view work.W1H68XOB as
      select
         PARTY_RK,
         (SUBSTR(PARTY_ID,5)) as PARTY_ID length = 50
            format = $50.
            informat = $50.
            label = 'PARTY_ID'
   from &SOURCEDS
      where PARTY_TYPE_CD = "FCFSUB"  & PARTY_CATEGORY_CD = "HHD"
   ;
quit;

%let SOURCEDS = work.W1H68XOB;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002P0 * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 * Target Table:    Extract - work.W1H69DWS               A5DG55RP.BR0001S3 * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(ecm_db.PARTY_LIVE); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H69DWS;
quit;

proc sql;
   create view work.W1H69DWS as
      select
         PARTY_RK,
         (SUBSTR(PARTY_ID,5)) as PARTY_ID length = 50
            format = $50.
            informat = $50.
            label = 'PARTY_ID'
   from &SOURCEDS
      where PARTY_TYPE_CD = "FCFSUB"  & PARTY_CATEGORY_CD = "ACC"
   ;
quit;

%let SOURCEDS = work.W1H69DWS;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002P1 * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 * Target Table:    Extract - work.W1H69VML               A5DG55RP.BR0001S4 * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(ecm_db.PARTY_LIVE); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H69VML;
quit;

proc sql;
   create view work.W1H69VML as
      select
         PARTY_RK,
         (SUBSTR(PARTY_ID,5)) as PARTY_ID length = 50
            format = $50.
            informat = $50.
            label = 'PARTY_ID'
   from &SOURCEDS
      where PARTY_TYPE_CD = "FCFSUB"  & PARTY_CATEGORY_CD = "PTY"
   ;
quit;

%let SOURCEDS = work.W1H69VML;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002P2 * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.WPG8GGA2                A5DG55RP.BR0001RX * 
 *                  Extract - work.W1H68XOB               A5DG55RP.BR0001S2 * 
 *                  Extract - work.W1H69VML               A5DG55RP.BR0001S4 * 
 * Target Table:    Lookup - work.W1H03BKC                A5DG55RP.BR0001S5 * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete etls_temp_lookupview1;
quit;

proc sql; create view etls_temp_lookupview1 as 
   select 
      PARTY_RK as ETLS_W2PJYY2L,
      PARTY_ID
   from work.W1H69VML
   ;
quit;
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2PJYY2M;
quit;

DATA  work.W2PJYY2M
         (keep = household_party_rk party_party_rk MEMBER_TYPE_CD )
      ; 
   
   attrib household_party_rk length=8 format=11. label="PARTY_RK"
          party_party_rk length=8 format=11. label="PARTY_RK"
          MEMBER_TYPE_CD length=$10 format=$10. label="MEMBER_TYPE_CD"
          PARTY_RK length= 8
          PARTY_ID length= $50
          ETLS_W2PJYY2L length= 8
          ; 
   
   retain missing0-missing1 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table work.W1H68XOB */ 
      nlobs = .; 
      dsid = open("work.W1H68XOB"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "work.W1H68XOB", hashexp: exponent);
            h0.defineKey( "PARTY_ID");
            h0.defineData( "PARTY_RK");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: work.W1H68XOB";
                  missing0 = 98; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: work.W1H68XOB";
            missing0 = 98; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened: work.W1H68XOB";
         
         missing0 = 99; 
      end; 
      
      /* Build hash h1 from lookup table etls_temp_lookupview1 */ 
      nlobs = .; 
      dsid = open("etls_temp_lookupview1"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h1(dataset: "etls_temp_lookupview1", hashexp: exponent);
            h1.defineKey( "PARTY_ID");
            h1.defineData( "ETLS_W2PJYY2L");
            h1.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h1.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: etls_temp_lookupview1";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " etls_temp_lookupview1";
                  
                  abort 4; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: etls_temp_lookupview1";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " etls_temp_lookupview1";
            
            abort 4; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " etls_temp_lookupview1";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " etls_temp_lookupview1";
         
         abort 4; 
      end; 
      
      call missing (PARTY_ID, PARTY_RK, ETLS_W2PJYY2L); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.WPG8GGA2 end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   if (missing0 < 1) then 
   do; 
      rc0 = h0.find(key: HOUSEHOLD_NUMBER);
      household_party_rk = PARTY_RK;
   end; 
   else 
      rc0 = missing0; 
      
   /* Is the current key value stored in hash h1?  */ 
   rc1 = h1.find(key: PARTY_NUMBER);
   party_party_rk = ETLS_W2PJYY2L;
   /* Examine success of lookups  */ 
   if ( rc0=0 and rc1=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W2PJYY2M; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         if (rc0 = 99) then 
         do; 
            /* Check: Lookup table missing-Write exception row  */ 
            /* Check: Lookup table missing-Set target columns to value  */ 
         end; 
         
         else if (rc0 = 98) then 
         do; 
            /* Check: Lookup table has no rows-Write exception row  */ 
            /* Check: Lookup table has no rows-Set target columns to value  */ 
         end; 
         
         else 
         do; 
            /* Check: Lookup value not found-Set target columns to missing  */ 
            call missing (household_party_rk); 
            etls_assign_target_value = 1; 
         end; 
      end; 
      
      if (rc1 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (party_party_rk); 
         etls_assign_target_value = 1; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.W2PJYY2M; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H03BKC;
quit;

proc sql;
   create table work.W1H03BKC as
      select
         household_party_rk,
         party_party_rk,
         ("HHD2PTY") as MEMBER_TYPE_CD length = 10
            format = $10.
            informat = $10.
            label = 'MEMBER_TYPE_CD'
   from work.W2PJYY2M
   ;
quit;

%let SOURCEDS = work.W1H03BKC;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2PJYY2M;
quit;

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002P3 * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.WPG8I50R                A5DG55RP.BR0001RZ * 
 *                  Extract - work.W1H68XOB               A5DG55RP.BR0001S2 * 
 *                  Extract - work.W1H69DWS               A5DG55RP.BR0001S3 * 
 * Target Table:    Lookup - work.W1H080IO                A5DG55RP.BR0001S6 * 
 *==========================================================================*/ 

/* Creating view to eliminate column name collisions for lookup table  */ 
/*  work.W1H69DWS                                                      */ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete etls_temp_lookupview1;
quit;

proc sql; create view etls_temp_lookupview1 as 
   select 
      PARTY_RK as ETLS_W2PJYY3G,
      PARTY_ID
   from work.W1H69DWS
   ;
quit;
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2PJYY3H;
quit;

DATA  work.W2PJYY3H
         (keep = household_party_rk account_party_rk MEMBER_TYPE_CD )
      ; 
   
   attrib household_party_rk length=8 format=11. label="PARTY_RK"
          account_party_rk length=8 format=11. label="PARTY_RK"
          MEMBER_TYPE_CD length=$10 format=$10. label="MEMBER_TYPE_CD"
          PARTY_RK length= 8
          PARTY_ID length= $50
          ETLS_W2PJYY3G length= 8
          ; 
   
   retain missing0-missing1 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table work.W1H68XOB */ 
      nlobs = .; 
      dsid = open("work.W1H68XOB"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "work.W1H68XOB", hashexp: exponent);
            h0.defineKey( "PARTY_ID");
            h0.defineData( "PARTY_RK");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: work.W1H68XOB";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " work.W1H68XOB";
                  
                  abort 4; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: work.W1H68XOB";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " work.W1H68XOB";
            
            abort 4; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened: work.W1H68XOB";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " work.W1H68XOB";
         
         abort 4; 
      end; 
      
      /* Build hash h1 from lookup table etls_temp_lookupview1 */ 
      nlobs = .; 
      dsid = open("etls_temp_lookupview1"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h1(dataset: "etls_temp_lookupview1", hashexp: exponent);
            h1.defineKey( "PARTY_ID");
            h1.defineData( "ETLS_W2PJYY3G");
            h1.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h1.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: etls_temp_lookupview1";
                  missing1 = 98; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: etls_temp_lookupview1";
            missing1 = 98; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " etls_temp_lookupview1";
         
         missing1 = 99; 
      end; 
      
      call missing (PARTY_ID, PARTY_RK, ETLS_W2PJYY3G); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.WPG8I50R end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: HOUSEHOLD_NUMBER);
   household_party_rk = PARTY_RK;
   /* Is the current key value stored in hash h1?  */ 
   if (missing1 < 1) then 
   do; 
      rc1 = h1.find(key: ACCOUNT_NUMBER);
      account_party_rk = ETLS_W2PJYY3G;
   end; 
   else 
      rc1 = missing1; 
      
   /* Examine success of lookups  */ 
   if ( rc0=0 and rc1=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W2PJYY3H; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (household_party_rk); 
         etls_assign_target_value = 1; 
      end; 
      
      if (rc1 ^= 0) then 
      do; 
         exception_total + 1; 
         if (rc1 = 99) then 
         do; 
            /* Check: Lookup table missing-Write exception row  */ 
            /* Check: Lookup table missing-Set target columns to value  */ 
         end; 
         
         else if (rc1 = 98) then 
         do; 
            /* Check: Lookup table has no rows-Write exception row  */ 
            /* Check: Lookup table has no rows-Set target columns to value  */ 
         end; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.W2PJYY3H; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H080IO;
quit;

proc sql;
   create table work.W1H080IO as
      select
         household_party_rk,
         account_party_rk,
         ("HHD2ACC") as MEMBER_TYPE_CD length = 10
            format = $10.
            informat = $10.
            label = 'MEMBER_TYPE_CD'
   from work.W2PJYY3H
   ;
quit;

%let SOURCEDS = work.W1H080IO;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2PJYY3H;
quit;

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002P4 * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.WPG8IV29                A5DG55RP.BR0001S1 * 
 *                  Extract - work.W1H69VML               A5DG55RP.BR0001S4 * 
 *                  Extract - work.W1H69DWS               A5DG55RP.BR0001S3 * 
 * Target Table:    Lookup - work.W1H0CT5V                A5DG55RP.BR0001S7 * 
 *==========================================================================*/ 

/* Creating view to eliminate column name collisions for lookup table  */ 
/*  work.W1H69DWS                                                      */ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete etls_temp_lookupview1;
quit;

proc sql; create view etls_temp_lookupview1 as 
   select 
      PARTY_RK as ETLS_W2PJYY49,
      PARTY_ID
   from work.W1H69DWS
   ;
quit;
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2PJYY4A;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.W2PJYY4A
         (keep = party_party_rk account_party_rk MEMBER_TYPE_CD )
      ; 
   
   attrib party_party_rk length=8 format=11. label="PARTY_RK"
          account_party_rk length=8 format=11. label="PARTY_RK"
          MEMBER_TYPE_CD length=$10 format=$10. label="MEMBER_TYPE_CD"
          PARTY_RK length= 8
          PARTY_ID length= $50
          ETLS_W2PJYY49 length= 8
          ; 
   
   retain missing0-missing1 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table work.W1H69VML */ 
      nlobs = .; 
      dsid = open("work.W1H69VML"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "work.W1H69VML", hashexp: exponent);
            h0.defineKey( "PARTY_ID");
            h0.defineData( "PARTY_RK");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: work.W1H69VML";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " work.W1H69VML";
                  
                  abort 4; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: work.W1H69VML";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " work.W1H69VML";
            
            abort 4; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened: work.W1H69VML";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " work.W1H69VML";
         
         abort 4; 
      end; 
      
      /* Build hash h1 from lookup table etls_temp_lookupview1 */ 
      nlobs = .; 
      dsid = open("etls_temp_lookupview1"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h1(dataset: "etls_temp_lookupview1", hashexp: exponent);
            h1.defineKey( "PARTY_ID");
            h1.defineData( "ETLS_W2PJYY49");
            h1.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h1.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: etls_temp_lookupview1";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " etls_temp_lookupview1";
                  
                  abort 4; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: etls_temp_lookupview1";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " etls_temp_lookupview1";
            
            abort 4; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " etls_temp_lookupview1";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " etls_temp_lookupview1";
         
         abort 4; 
      end; 
      
      call missing (PARTY_ID, PARTY_RK, ETLS_W2PJYY49); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.WPG8IV29 end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: PARTY_NUMBER);
   party_party_rk = PARTY_RK;
   /* Is the current key value stored in hash h1?  */ 
   rc1 = h1.find(key: ACCOUNT_NUMBER);
   account_party_rk = ETLS_W2PJYY49;
   /* Examine success of lookups  */ 
   if ( rc0=0 and rc1=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W2PJYY4A; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (party_party_rk); 
         etls_assign_target_value = 1; 
      end; 
      
      if (rc1 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (account_party_rk); 
         etls_assign_target_value = 1; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.W2PJYY4A; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H0CT5V;
quit;

proc sql;
   create table work.W1H0CT5V as
      select
         party_party_rk,
         account_party_rk,
         ("PTY2ACC") as MEMBER_TYPE_CD length = 10
            format = $10.
            informat = $10.
            label = 'MEMBER_TYPE_CD'
   from work.W2PJYY4A
   ;
quit;

%let SOURCEDS = work.W1H0CT5V;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2PJYY4A;
quit;

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Append                                A5DG55RP.BV0002P5 * 
 * Transform:       Append                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W1H03BKC                A5DG55RP.BR0001S5 * 
 *                  Lookup - work.W1H080IO                A5DG55RP.BR0001S6 * 
 *                  Lookup - work.W1H0CT5V                A5DG55RP.BR0001S7 * 
 * Target Table:    Append - work.W494Z1RQ                A5DG55RP.BR0001S8 * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2PJYY50;
quit;

proc sql;
   create view work.W2PJYY50 as
      select
         household_party_rk as SOURCE_PARTY_RK,
         party_party_rk as TARGET_PARTY_RK,
         MEMBER_TYPE_CD
   from work.W1H03BKC
   ;
quit;


proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2PJYY54;
quit;

proc sql;
   create view work.W2PJYY54 as
      select
         household_party_rk as SOURCE_PARTY_RK,
         account_party_rk as TARGET_PARTY_RK,
         MEMBER_TYPE_CD
   from work.W1H080IO
   ;
quit;


proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2PJYY57;
quit;

proc sql;
   create view work.W2PJYY57 as
      select
         party_party_rk as SOURCE_PARTY_RK,
         account_party_rk as TARGET_PARTY_RK,
         MEMBER_TYPE_CD
   from work.W1H0CT5V
   ;
quit;


proc datasets lib = work nolist nowarn memtype = (data view);
   delete W494Z1RQ;
quit;

data work.W494Z1RQ / view=work.W494Z1RQ;
   set work.W2PJYY50
       work.W2PJYY54
       work.W2PJYY57;
   keep SOURCE_PARTY_RK TARGET_PARTY_RK MEMBER_TYPE_CD; 
run;

/**  Step end Append **/

/*==========================================================================* 
 * Step:            Delete                                A5DG55RP.BV0002P6 * 
 * Transform:       Delete                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Append - work.W494Z1RQ                A5DG55RP.BR0001S8 * 
 *                  PARTY_X_PARTY - ecm_db.PARTY_X_PARTY  A5DG55RP.BH0001A0 * 
 * Target Table:    PARTY_X_PARTY - ecm_db.PARTY_X_PARTY  A5DG55RP.BH0001A0 * 
 *==========================================================================*/ 

   /*---- Delete the target table  ----*/ 
   proc sql;
      delete from ecm_db.PARTY_X_PARTY
      where
         PARTY_X_PARTY.PARTY_RK IN (
            select
               PARTY_X_PARTY.PARTY_RK length = 8   
                  format = 11.
                  informat = 11.
                  label = 'PARTY_RK'
            from
               work.W494Z1RQ as W494Z1RQ inner join 
               ecm_db.PARTY_X_PARTY as PARTY_X_PARTY
                  on
                  (
                     W494Z1RQ.SOURCE_PARTY_RK = PARTY_X_PARTY.PARTY_RK
                     and W494Z1RQ.TARGET_PARTY_RK = PARTY_X_PARTY.MEMBER_PARTY_RK
                  )
         )
   ;quit;

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002P7 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Append - work.W494Z1RQ                A5DG55RP.BR0001S8 * 
 * Target Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W494Z1RQ); 

   data _null_;
      call symput('current_dt',put(datetime(),datetime22.));
   run;

   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W2PJYYEE;
   quit;
   
   proc sql;
      create view work.W2PJYYEE as
         select
            . as EVENT_RK length = 8
               format = 11.
               informat = 11.,
			("PARTY") as BUSINESS_OBJECT_NM length = 100
               format = $100.
               informat = $100.,
            SOURCE_PARTY_RK as BUSINESS_OBJECT_RK,
            ("REMPAR") as EVENT_TYPE_CD length = 10
               format = $10.
               informat = $10.,
            ("Remove Dim to Dim link") as EVENT_DESC length = 256
               format = $256.
               informat = $256.,
            ("sysadmin") as CREATE_USER_ID length = 60
               format = $60.
               informat = $60.,
            ("&current_dt"dt) as CREATE_DTTM length = 8
               format = DATETIME27.6
               informat = DATETIME27.6,
            ("PARTY") as LINKED_OBJECT_NM length = 100
               format = $100.
               informat = $100.,
            TARGET_PARTY_RK as LINKED_OBJECT_RK
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W2PJYYEE;
   
   proc datasets lib = iem nolist nowarn memtype = (data view);
      delete new_events;
   quit;
   
   data iem.new_events;
      attrib EVENT_RK length = 8
         format = 11.
         informat = 11.
         label = 'EVENT_RK';
      attrib BUSINESS_OBJECT_NM length = $100
         format = $100.
         informat = $100.
         label = 'BUSINESS_OBJECT_NM'; 
      attrib BUSINESS_OBJECT_RK length = 8
         format = 11.
         informat = 11.
         label = 'BUSINESS_OBJECT_RK'; 
      attrib EVENT_TYPE_CD length = $10
         format = $10.
         informat = $10.
         label = 'EVENT_TYPE_CD'; 
      attrib EVENT_DESC length = $256
         format = $256.
         informat = $256.
         label = 'EVENT_DESC'; 
      attrib CREATE_USER_ID length = $60
         format = $60.
         informat = $60.
         label = 'CREATE_USER_ID'; 
      attrib CREATE_DTTM length = 8
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'CREATE_DTTM'; 
      attrib LINKED_OBJECT_NM length = $100
         format = $100.
         informat = $100.
         label = 'LINKED_OBJECT_NM'; 
      attrib LINKED_OBJECT_RK length = 8
         format = 11.
         informat = 11.
         label = 'LINKED_OBJECT_RK'; 
      call missing(of _all_);
      stop;
   run;
   
proc append base = iem.new_events 
   data = &SOURCEDS force ; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2PJYYEE;
quit;

/*---- Start of Post-Process Code  ----*/ 

%let obs_count = %fcf_get_observation_count(table=iem.new_events, SASDATASET=Y);
%let numevents = &obs_count;

%fcf_get_ecm_sequence_ids(numIDs=&numevents, ecmSeq=event);

data iem.new_events;
	set iem.new_events;
	event_rk = symgetn('seqId'||(kstrip(put(_n_,best32.))));
run;
/*---- End of Post-Process Code  ----*/ 

/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002P8 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 * Target Table:    ECM_EVENT - ecm_db.ECM_EVENT          A5DG55RP.BH00019J * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.new_events); 
      
   proc append base = ecm_db.ECM_EVENT 
      data = &SOURCEDS  force ; 
    run; 
      
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W2PJYYF8;
   quit;
 
/**  Step end Table Loader **/

%mend;
