%macro fcf_iem_fb_party;

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002YG * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 * Target Table:    Extract - work.WEV3G32                A5DG55RP.BR0001WE * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(ecm_db.PARTY_LIVE); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete WEV3G32;
quit;

proc sql;
   create view work.WEV3G32 as
      select
         PARTY_RK,
         VALID_FROM_DTTM
   from &SOURCEDS
      where SOURCE_SYSTEM_CD = "&segKCschema" & PARTY_TYPE_CD = 'FCFSUB' & PARTY_CATEGORY_CD = 'PTY'
   ;
quit;

%let SOURCEDS = work.WEV3G32;

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002YH * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Extract - work.WEV3G32                A5DG55RP.BR0001WE * 
 *                  PARTY_UDF_NUM_VALUE -                 A5DG55RP.BH00019Y * 
 *                   ecm_db.PARTY_UDF_NUM_VALUE                             * 
 * Target Table:    Lookup - work.WEWDNU8                 A5DG55RP.BR0001WF * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete etls_temp_lookupview0;
quit;

proc sql; create view etls_temp_lookupview0 as 
   select * from ecm_db.PARTY_UDF_NUM_VALUE
   where UDF_NM = 'X_SASFCS_RSK_CLSSF';
quit;
proc datasets lib = work nolist nowarn memtype = (data view);
   delete WEWDNU8;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.WEWDNU8
         (keep = PARTY_RK VALID_FROM_DTTM RISK_CLASSIFICATION )
      ; 
   
   attrib PARTY_RK length=8 format=11. label="PARTY_RK"
          VALID_FROM_DTTM length=8 format=DATETIME27.6 label="VALID_FROM_DTTM"
          RISK_CLASSIFICATION length=8 label="UDF_VALUE"
          UDF_VALUE length= 8
          ; 
   
   retain missing0-missing0 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table etls_temp_lookupview0 */ 
      nlobs = .; 
      dsid = open("etls_temp_lookupview0"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "etls_temp_lookupview0", hashexp: exponent);
            h0.defineKey( "PARTY_RK",
                           "VALID_FROM_DTTM");
            h0.defineData( "UDF_VALUE");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: etls_temp_lookupview0";
                  missing0 = 98; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: etls_temp_lookupview0";
            missing0 = 98; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " etls_temp_lookupview0";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " etls_temp_lookupview0";
         
         abort 3; 
      end; 
      
      call missing (PARTY_RK, VALID_FROM_DTTM, UDF_VALUE); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.WEV3G32 end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   if (missing0 < 1) then 
   do; 
      rc0 = h0.find(key: PARTY_RK, key: VALID_FROM_DTTM);
      RISK_CLASSIFICATION = UDF_VALUE;
   end; 
   else 
      rc0 = missing0; 
      
   /* Examine success of lookups  */ 
   if ( rc0=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.WEWDNU8; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         if (rc0 = 98) then 
         do; 
            /* Check: Lookup table has no rows-Write exception row  */ 
            /* Check: Lookup table has no rows-Set target columns to value  */ 
            RISK_CLASSIFICATION =.;
            etls_assign_target_value = 1; 
         end; 
         
         else 
         do; 
            /* Check: Lookup value not found-Set target columns to value  */ 
            RISK_CLASSIFICATION =.;
            etls_assign_target_value = 1; 
         end; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.WEWDNU8; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV00031C * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.WEWDNU8                 A5DG55RP.BR0001WF * 
 *                  PARTY_UDF_NUM_VALUE -                 A5DG55RP.BH00019Y * 
 *                   ecm_db.PARTY_UDF_NUM_VALUE                             * 
 * Target Table:    Lookup - work.W5BQVLFW                A5DG55RP.BR0001XX * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete etls_temp_lookupview0;
quit;

proc sql; create view etls_temp_lookupview0 as 
   select * from ecm_db.PARTY_UDF_NUM_VALUE
   where UDF_NM = 'X_SASFCS_PTY_KEY';
quit;
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5BQVLFW;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.W5BQVLFW
         (keep = PARTY_RK VALID_FROM_DTTM RISK_CLASSIFICATION PARTY_key )
      ; 
   
   attrib PARTY_RK length=8 format=11. label="PARTY_RK"
          VALID_FROM_DTTM length=8 format=DATETIME27.6 label="VALID_FROM_DTTM"
          RISK_CLASSIFICATION length=8 label="UDF_VALUE"
          PARTY_key length=8 label="UDF_VALUE"
          UDF_VALUE length= 8
          ; 
   
   retain missing0-missing0 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table etls_temp_lookupview0 */ 
      nlobs = .; 
      dsid = open("etls_temp_lookupview0"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "etls_temp_lookupview0", hashexp: exponent);
            h0.defineKey( "PARTY_RK",
                           "VALID_FROM_DTTM");
            h0.defineData( "UDF_VALUE");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: etls_temp_lookupview0";
                  missing0 = 98; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: etls_temp_lookupview0";
            missing0 = 98; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " etls_temp_lookupview0";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " etls_temp_lookupview0";
         
         abort 3; 
      end; 
      
      call missing (PARTY_RK, VALID_FROM_DTTM, UDF_VALUE); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.WEWDNU8 end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   if (missing0 < 1) then 
   do; 
      rc0 = h0.find(key: PARTY_RK, key: VALID_FROM_DTTM);
      PARTY_key = UDF_VALUE;
   end; 
   else 
      rc0 = missing0; 
      
   /* Examine success of lookups  */ 
   if ( rc0=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W5BQVLFW; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         if (rc0 = 98) then 
         do; 
            /* Check: Lookup table has no rows-Write exception row  */ 
            /* Check: Lookup table has no rows-Set target columns to value  */ 
            PARTY_key =.;
            etls_assign_target_value = 1; 
         end; 
         
         else 
         do; 
            /* Check: Lookup value not found-Set target columns to value  */ 
            PARTY_key =.;
            etls_assign_target_value = 1; 
         end; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.W5BQVLFW; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 


/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV00032L * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W5BQVLFW                A5DG55RP.BR0001XX * 
 *                  FSC_PARTY_DIM - 										*
 *                   &db_core_libname..FSC_PARTY_DIM      A5DG55RP.BH00019F * 
 * Target Tables:   Lookup - work.WDHFSY74                A5DG55RP.BR0001Z3 * 
 *                  Error Table - work.W68RIBZD           A5DG55RP.BR0001Z4 * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W68RIBZD;
quit;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8AJ77W3;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.W8AJ77W3
         (keep = PARTY_RK VALID_FROM_DTTM PARTY_key SEGMENT_ID PARTY_NUMBER 
                 PARTY_TYPE_DESC PARTY_TAX_ID PARTY_TAX_ID_TYPE_CODE 
                 PARTY_IDENTIFICATION_ID PARTY_IDENTIFICATION_TYPE_DESC 
                 PARTY_ID_STATE_CODE PARTY_DATE_OF_BIRTH PARTY_FIRST_NAME 
                 PARTY_LAST_NAME PARTY_MIDDLE_NAME PARTY_NAME DOING_BUSINESS_AS_NAME 
                 PARTY_STATUS_DESC ULTIMATE_PARENT_NAME MATCH_CODE_ORGANIZATION 
                 MATCH_CODE_INDIVIDUAL MATCH_CODE_STREET_ADDRESS 
                 MATCH_CODE_MAILING_ADDRESS STREET_ADDRESS_1 STREET_ADDRESS_2 
                 STREET_CITY_NAME STREET_STATE_CODE STREET_STATE_NAME 
                 STREET_POSTAL_CODE STREET_COUNTRY_CODE STREET_COUNTRY_NAME 
                 MAILING_ADDRESS_1 MAILING_ADDRESS_2 MAILING_CITY_NAME 
                 MAILING_STATE_CODE MAILING_STATE_NAME MAILING_POSTAL_CODE 
                 MAILING_COUNTRY_CODE MAILING_COUNTRY_NAME RESIDENCE_COUNTRY_CODE 
                 RESIDENCE_COUNTRY_NAME CITIZENSHIP_COUNTRY_CODE 
                 CITIZENSHIP_COUNTRY_NAME ORG_COUNTRY_OF_BUSINESS_CODE 
                 ORG_COUNTRY_OF_BUSINESS_NAME EMPLOYEE_IND EMPLOYEE_NUMBER 
                 EMPLOYER_NAME EMPLOYER_PHONE_NUMBER EMAIL_ADDRESS OCCUPATION_DESC 
                 INDUSTRY_CODE INDUSTRY_DESC PHONE_NUMBER_1 PHONE_NUMBER_2 
                 PHONE_NUMBER_3 ANNUAL_INCOME_AMOUNT NET_WORTH_AMOUNT 
                 MARITAL_STATUS_DESC LAST_CONTACT_DATE POLITICALLY_EXPOSED_PERSON_IND 
                 NON_PROFIT_ORG_IND CUSTOMER_SINCE_DATE LAST_SUSP_ACTV_RPT_DATE 
                 LAST_CASH_TRANS_RPT_DATE LAST_RISK_ASSESSMENT_DATE RISK_CLASSIFICATION 
                 CHANGE_BEGIN_DATE CHANGE_END_DATE CHANGE_CURRENT_IND )
      work.W68RIBZD
         (keep = PARTY_RK VALID_FROM_DTTM RISK_CLASSIFICATION PARTY_key); 
   
   attrib etls_exception_cond etls_exception_action length=$32
          etls_lookup_table length=$41
          PARTY_RK length=8 format=11. label="PARTY_RK"
          VALID_FROM_DTTM length=8 format=DATETIME27.6 label="VALID_FROM_DTTM"
          PARTY_key length=8 label="UDF_VALUE"
          SEGMENT_ID length=$128 format=$128. label="SEGMENT_ID"
          PARTY_NUMBER length=$50 format=$50. label="PARTY_NUMBER"
          PARTY_TYPE_DESC length=$20 format=$20. label="PARTY_TYPE_DESC"
          PARTY_TAX_ID length=$35 format=$35. label="PARTY_TAX_ID"
          PARTY_TAX_ID_TYPE_CODE length=$1 format=$1. label="PARTY_TAX_ID_TYPE_CODE"
          PARTY_IDENTIFICATION_ID length=$35 format=$35. label="PARTY_IDENTIFICATION_ID"
          PARTY_IDENTIFICATION_TYPE_DESC length=$4 format=$4. label="PARTY_IDENTIFICATION_TYPE_DESC"
          PARTY_ID_STATE_CODE length=$3 format=$3. label="PARTY_ID_STATE_CODE"
          PARTY_DATE_OF_BIRTH length=8 format=DATETIME20. label="PARTY_DATE_OF_BIRTH"
          PARTY_FIRST_NAME length=$50 format=$50. label="PARTY_FIRST_NAME"
          PARTY_LAST_NAME length=$50 format=$50. label="PARTY_LAST_NAME"
          PARTY_MIDDLE_NAME length=$100 format=$100. label="PARTY_MIDDLE_NAME"
          PARTY_NAME length=$200 format=$200. label="PARTY_NAME"
          DOING_BUSINESS_AS_NAME length=$35 format=$35. label="DOING_BUSINESS_AS_NAME"
          PARTY_STATUS_DESC length=$20 format=$20. label="PARTY_STATUS_DESC"
          ULTIMATE_PARENT_NAME length=$35 format=$35. label="ULTIMATE_PARENT_NAME"
          MATCH_CODE_ORGANIZATION length=$80 format=$80. label="MATCH_CODE_ORGANIZATION"
          MATCH_CODE_INDIVIDUAL length=$80 format=$80. label="MATCH_CODE_INDIVIDUAL"
          MATCH_CODE_STREET_ADDRESS length=$80 format=$80. label="MATCH_CODE_STREET_ADDRESS"
          MATCH_CODE_MAILING_ADDRESS length=$80 format=$80. label="MATCH_CODE_MAILING_ADDRESS"
          STREET_ADDRESS_1 length=$35 format=$35. label="STREET_ADDRESS_1"
          STREET_ADDRESS_2 length=$35 format=$35. label="STREET_ADDRESS_2"
          STREET_CITY_NAME length=$35 format=$35. label="STREET_CITY_NAME"
          STREET_STATE_CODE length=$3 format=$3. label="STREET_STATE_CODE"
          STREET_STATE_NAME length=$35 format=$35. label="STREET_STATE_NAME"
          STREET_POSTAL_CODE length=$10 format=$10. label="STREET_POSTAL_CODE"
          STREET_COUNTRY_CODE length=$3 format=$3. label="STREET_COUNTRY_CODE"
          STREET_COUNTRY_NAME length=$100 format=$100. label="STREET_COUNTRY_NAME"
          MAILING_ADDRESS_1 length=$35 format=$35. label="MAILING_ADDRESS_1"
          MAILING_ADDRESS_2 length=$35 format=$35. label="MAILING_ADDRESS_2"
          MAILING_CITY_NAME length=$35 format=$35. label="MAILING_CITY_NAME"
          MAILING_STATE_CODE length=$3 format=$3. label="MAILING_STATE_CODE"
          MAILING_STATE_NAME length=$35 format=$35. label="MAILING_STATE_NAME"
          MAILING_POSTAL_CODE length=$10 format=$10. label="MAILING_POSTAL_CODE"
          MAILING_COUNTRY_CODE length=$3 format=$3. label="MAILING_COUNTRY_CODE"
          MAILING_COUNTRY_NAME length=$100 format=$100. label="MAILING_COUNTRY_NAME"
          RESIDENCE_COUNTRY_CODE length=$3 format=$3. label="RESIDENCE_COUNTRY_CODE"
          RESIDENCE_COUNTRY_NAME length=$100 format=$100. label="RESIDENCE_COUNTRY_NAME"
          CITIZENSHIP_COUNTRY_CODE length=$3 format=$3. label="CITIZENSHIP_COUNTRY_CODE"
          CITIZENSHIP_COUNTRY_NAME length=$100 format=$100. label="CITIZENSHIP_COUNTRY_NAME"
          ORG_COUNTRY_OF_BUSINESS_CODE length=$3 format=$3. label="ORG_COUNTRY_OF_BUSINESS_CODE"
          ORG_COUNTRY_OF_BUSINESS_NAME length=$100 format=$100. label="ORG_COUNTRY_OF_BUSINESS_NAME"
          EMPLOYEE_IND length=$1 format=$1. label="EMPLOYEE_IND"
          EMPLOYEE_NUMBER length=$20 format=$20. label="EMPLOYEE_NUMBER"
          EMPLOYER_NAME length=$35 format=$35. label="EMPLOYER_NAME"
          EMPLOYER_PHONE_NUMBER length=$25 format=$25. label="EMPLOYER_PHONE_NUMBER"
          EMAIL_ADDRESS length=$35 format=$35. label="EMAIL_ADDRESS"
          OCCUPATION_DESC length=$35 format=$35. label="OCCUPATION_DESC"
          INDUSTRY_CODE length=$10 format=$10. label="INDUSTRY_CODE"
          INDUSTRY_DESC length=$255 format=$255. label="INDUSTRY_DESC"
          PHONE_NUMBER_1 length=$25 format=$25. label="PHONE_NUMBER_1"
          PHONE_NUMBER_2 length=$25 format=$25. label="PHONE_NUMBER_2"
          PHONE_NUMBER_3 length=$25 format=$25. label="PHONE_NUMBER_3"
          ANNUAL_INCOME_AMOUNT length=8 format=11. label="ANNUAL_INCOME_AMOUNT"
          NET_WORTH_AMOUNT length=8 format=11. label="NET_WORTH_AMOUNT"
          MARITAL_STATUS_DESC length=$20 format=$20. label="MARITAL_STATUS_DESC"
          LAST_CONTACT_DATE length=8 format=DATETIME20. label="LAST_CONTACT_DATE"
          POLITICALLY_EXPOSED_PERSON_IND length=$1 format=$1. label="POLITICALLY_EXPOSED_PERSON_IND"
          NON_PROFIT_ORG_IND length=$1 format=$1. label="NON_PROFIT_ORG_IND"
          CUSTOMER_SINCE_DATE length=8 format=DATETIME20. label="CUSTOMER_SINCE_DATE"
          LAST_SUSP_ACTV_RPT_DATE length=8 format=DATETIME20. label="LAST_SUSP_ACTV_RPT_DATE"
          LAST_CASH_TRANS_RPT_DATE length=8 format=DATETIME20. label="LAST_CASH_TRANS_RPT_DATE"
          LAST_RISK_ASSESSMENT_DATE length=8 format=DATETIME27.6 label="CREATE_DTTM"
          RISK_CLASSIFICATION length=8 label="UDF_VALUE"
          CHANGE_BEGIN_DATE length=8 format=DATETIME20. label="CHANGE_BEGIN_DATE"
          CHANGE_END_DATE length=8 format=DATETIME20. label="CHANGE_END_DATE"
          CHANGE_CURRENT_IND length=$1 format=$1. label="CHANGE_CURRENT_IND"
          ; 
   
   retain missing0-missing0 0; 
   
   etls_assign_target_value = 0; 
   /* Assign variables used for error/exception handling  */ 
   etls_source_row      = _n_;
   etls_write_to_error_table  = 0; 
   
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table &db_core_libname..FSC_PARTY_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_PARTY_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "&db_core_libname..FSC_PARTY_DIM", hashexp: exponent);
            h0.defineKey( "PARTY_KEY",
                           "RISK_CLASSIFICATION");
            h0.defineData( "SEGMENT_ID",
                           "PARTY_NUMBER",
                           "PARTY_TYPE_DESC",
                           "PARTY_TAX_ID",
                           "PARTY_TAX_ID_TYPE_CODE",
                           "PARTY_IDENTIFICATION_ID",
                           "PARTY_IDENTIFICATION_TYPE_DESC",
                           "PARTY_ID_STATE_CODE",
                           "PARTY_DATE_OF_BIRTH",
                           "PARTY_FIRST_NAME",
                           "PARTY_LAST_NAME",
                           "PARTY_MIDDLE_NAME",
                           "PARTY_NAME",
                           "DOING_BUSINESS_AS_NAME",
                           "PARTY_STATUS_DESC",
                           "ULTIMATE_PARENT_NAME",
                           "MATCH_CODE_ORGANIZATION",
                           "MATCH_CODE_INDIVIDUAL",
                           "MATCH_CODE_STREET_ADDRESS",
                           "MATCH_CODE_MAILING_ADDRESS",
                           "STREET_ADDRESS_1",
                           "STREET_ADDRESS_2",
                           "STREET_CITY_NAME",
                           "STREET_STATE_CODE",
                           "STREET_STATE_NAME",
                           "STREET_POSTAL_CODE",
                           "STREET_COUNTRY_CODE",
                           "STREET_COUNTRY_NAME",
                           "MAILING_ADDRESS_1",
                           "MAILING_ADDRESS_2",
                           "MAILING_CITY_NAME",
                           "MAILING_STATE_CODE",
                           "MAILING_STATE_NAME",
                           "MAILING_POSTAL_CODE",
                           "MAILING_COUNTRY_CODE",
                           "MAILING_COUNTRY_NAME",
                           "RESIDENCE_COUNTRY_CODE",
                           "RESIDENCE_COUNTRY_NAME",
                           "CITIZENSHIP_COUNTRY_CODE",
                           "CITIZENSHIP_COUNTRY_NAME",
                           "ORG_COUNTRY_OF_BUSINESS_CODE",
                           "ORG_COUNTRY_OF_BUSINESS_NAME",
                           "EMPLOYEE_IND",
                           "EMPLOYEE_NUMBER",
                           "EMPLOYER_NAME",
                           "EMPLOYER_PHONE_NUMBER",
                           "EMAIL_ADDRESS",
                           "OCCUPATION_DESC",
                           "INDUSTRY_CODE",
                           "INDUSTRY_DESC",
                           "PHONE_NUMBER_1",
                           "PHONE_NUMBER_2",
                           "PHONE_NUMBER_3",
                           "ANNUAL_INCOME_AMOUNT",
                           "NET_WORTH_AMOUNT",
                           "MARITAL_STATUS_DESC",
                           "LAST_CONTACT_DATE",
                           "POLITICALLY_EXPOSED_PERSON_IND",
                           "NON_PROFIT_ORG_IND",
                           "CUSTOMER_SINCE_DATE",
                           "LAST_SUSP_ACTV_RPT_DATE",
                           "LAST_CASH_TRANS_RPT_DATE",
                           "CHANGE_BEGIN_DATE",
                           "CHANGE_END_DATE",
                           "CHANGE_CURRENT_IND");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_PARTY_DIM";
                  missing0 = 98; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_PARTY_DIM";
            missing0 = 98; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_PARTY_DIM";
         
         missing0 = 99; 
      end; 
      
      call missing (PARTY_KEY, RISK_CLASSIFICATION, SEGMENT_ID, PARTY_NUMBER, 
                    PARTY_TYPE_DESC, PARTY_TAX_ID, PARTY_TAX_ID_TYPE_CODE, 
                    PARTY_IDENTIFICATION_ID, PARTY_IDENTIFICATION_TYPE_DESC, 
                    PARTY_ID_STATE_CODE, PARTY_DATE_OF_BIRTH, PARTY_FIRST_NAME, 
                    PARTY_LAST_NAME, PARTY_MIDDLE_NAME, PARTY_NAME, 
                    DOING_BUSINESS_AS_NAME, PARTY_STATUS_DESC, ULTIMATE_PARENT_NAME, 
                    MATCH_CODE_ORGANIZATION, MATCH_CODE_INDIVIDUAL, 
                    MATCH_CODE_STREET_ADDRESS, MATCH_CODE_MAILING_ADDRESS, 
                    STREET_ADDRESS_1, STREET_ADDRESS_2, STREET_CITY_NAME, 
                    STREET_STATE_CODE, STREET_STATE_NAME, STREET_POSTAL_CODE, 
                    STREET_COUNTRY_CODE, STREET_COUNTRY_NAME, MAILING_ADDRESS_1, 
                    MAILING_ADDRESS_2, MAILING_CITY_NAME, MAILING_STATE_CODE, 
                    MAILING_STATE_NAME, MAILING_POSTAL_CODE, MAILING_COUNTRY_CODE, 
                    MAILING_COUNTRY_NAME, RESIDENCE_COUNTRY_CODE, 
                    RESIDENCE_COUNTRY_NAME, CITIZENSHIP_COUNTRY_CODE, 
                    CITIZENSHIP_COUNTRY_NAME, ORG_COUNTRY_OF_BUSINESS_CODE, 
                    ORG_COUNTRY_OF_BUSINESS_NAME, EMPLOYEE_IND, EMPLOYEE_NUMBER, 
                    EMPLOYER_NAME, EMPLOYER_PHONE_NUMBER, EMAIL_ADDRESS, 
                    OCCUPATION_DESC, INDUSTRY_CODE, INDUSTRY_DESC, PHONE_NUMBER_1, 
                    PHONE_NUMBER_2, PHONE_NUMBER_3, ANNUAL_INCOME_AMOUNT, 
                    NET_WORTH_AMOUNT, MARITAL_STATUS_DESC, LAST_CONTACT_DATE, 
                    POLITICALLY_EXPOSED_PERSON_IND, NON_PROFIT_ORG_IND, 
                    CUSTOMER_SINCE_DATE, LAST_SUSP_ACTV_RPT_DATE, 
                    LAST_CASH_TRANS_RPT_DATE, CHANGE_BEGIN_DATE, CHANGE_END_DATE, 
                    CHANGE_CURRENT_IND); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W5BQVLFW end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   if (missing0 < 1) then 
   do; 
      rc0 = h0.find(key: PARTY_key, key: RISK_CLASSIFICATION);
   end; 
   else 
      rc0 = missing0; 
      
   /* Examine success of lookups  */ 
   if ( rc0=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W8AJ77W3; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         if (rc0 = 99) then 
         do; 
            /* Check: Lookup table missing-Write exception row  */ 
            etls_write_to_error_table = 1; 
            /* Check: Lookup table missing-Set target columns to value  */ 
         end; 
         
         else if (rc0 = 98) then 
         do; 
            /* Check: Lookup table has no rows-Write exception row  */ 
            etls_write_to_error_table = 1; 
            /* Check: Lookup table has no rows-Set target columns to value  */ 
         end; 
         
         else 
         do; 
            etls_write_to_error_table = 1; 
         end; 
      end; 
      
      /* Write row to error table?  */ 
      if (etls_write_to_error_table eq 1) then 
         output work.W68RIBZD; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 



proc datasets lib = work nolist nowarn memtype = (data view);
   delete WDHFSY74;
quit;

proc sql;
   create table work.WDHFSY74 as
      select
         PARTY_RK,
         VALID_FROM_DTTM,
         PARTY_key,
         SEGMENT_ID,
         PARTY_NUMBER,
         PARTY_TYPE_DESC,
         PARTY_TAX_ID,
         PARTY_TAX_ID_TYPE_CODE,
         PARTY_IDENTIFICATION_ID,
         PARTY_IDENTIFICATION_TYPE_DESC,
         PARTY_ID_STATE_CODE,
         PARTY_DATE_OF_BIRTH,
         PARTY_FIRST_NAME,
         PARTY_LAST_NAME,
         PARTY_MIDDLE_NAME,
         PARTY_NAME,
         DOING_BUSINESS_AS_NAME,
         PARTY_STATUS_DESC,
         ULTIMATE_PARENT_NAME,
         MATCH_CODE_ORGANIZATION,
         MATCH_CODE_INDIVIDUAL,
         MATCH_CODE_STREET_ADDRESS,
         MATCH_CODE_MAILING_ADDRESS,
         STREET_ADDRESS_1,
         STREET_ADDRESS_2,
         STREET_CITY_NAME,
         STREET_STATE_CODE,
         STREET_STATE_NAME,
         STREET_POSTAL_CODE,
         STREET_COUNTRY_CODE,
         STREET_COUNTRY_NAME,
         MAILING_ADDRESS_1,
         MAILING_ADDRESS_2,
         MAILING_CITY_NAME,
         MAILING_STATE_CODE,
         MAILING_STATE_NAME,
         MAILING_POSTAL_CODE,
         MAILING_COUNTRY_CODE,
         MAILING_COUNTRY_NAME,
         RESIDENCE_COUNTRY_CODE,
         RESIDENCE_COUNTRY_NAME,
         CITIZENSHIP_COUNTRY_CODE,
         CITIZENSHIP_COUNTRY_NAME,
         ORG_COUNTRY_OF_BUSINESS_CODE,
         ORG_COUNTRY_OF_BUSINESS_NAME,
         EMPLOYEE_IND,
         EMPLOYEE_NUMBER,
         EMPLOYER_NAME,
         EMPLOYER_PHONE_NUMBER,
         EMAIL_ADDRESS,
         OCCUPATION_DESC,
         INDUSTRY_CODE,
         INDUSTRY_DESC,
         PHONE_NUMBER_1,
         PHONE_NUMBER_2,
         PHONE_NUMBER_3,
         ANNUAL_INCOME_AMOUNT,
         NET_WORTH_AMOUNT,
         MARITAL_STATUS_DESC,
         LAST_CONTACT_DATE,
         POLITICALLY_EXPOSED_PERSON_IND,
         NON_PROFIT_ORG_IND,
         CUSTOMER_SINCE_DATE,
         LAST_SUSP_ACTV_RPT_DATE,
         LAST_CASH_TRANS_RPT_DATE,
         VALID_FROM_DTTM as LAST_RISK_ASSESSMENT_DATE   
            label = 'CREATE_DTTM',
         RISK_CLASSIFICATION,
         CHANGE_BEGIN_DATE,
         CHANGE_END_DATE,
         CHANGE_CURRENT_IND
   from work.W8AJ77W3
   ;
quit;

%let SOURCEDS = work.WDHFSY74;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8AJ77W3;
quit;


/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV00032O * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Error Table - work.W68RIBZD           A5DG55RP.BR0001Z4 * 
 *                  FSC_PARTY_DIM -  										*
 *                   &db_core_libname..FSC_PARTY_DIM      A5DG55RP.BH00019F * 
 * Target Table:    Lookup - work.WDHK98OG                A5DG55RP.BR0001Z6 * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8AJ77XO;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.W8AJ77XO
         (keep = PARTY_KEY SEGMENT_ID PARTY_NUMBER PARTY_TYPE_DESC PARTY_TAX_ID 
                 PARTY_TAX_ID_TYPE_CODE PARTY_IDENTIFICATION_ID 
                 PARTY_IDENTIFICATION_TYPE_DESC PARTY_ID_STATE_CODE PARTY_DATE_OF_BIRTH 
                 PARTY_FIRST_NAME PARTY_LAST_NAME PARTY_MIDDLE_NAME PARTY_NAME 
                 DOING_BUSINESS_AS_NAME PARTY_STATUS_DESC ULTIMATE_PARENT_NAME 
                 MATCH_CODE_ORGANIZATION MATCH_CODE_INDIVIDUAL 
                 MATCH_CODE_STREET_ADDRESS MATCH_CODE_MAILING_ADDRESS STREET_ADDRESS_1 
                 STREET_ADDRESS_2 STREET_CITY_NAME STREET_STATE_CODE STREET_STATE_NAME 
                 STREET_POSTAL_CODE STREET_COUNTRY_CODE STREET_COUNTRY_NAME 
                 MAILING_ADDRESS_1 MAILING_ADDRESS_2 MAILING_CITY_NAME 
                 MAILING_STATE_CODE MAILING_STATE_NAME MAILING_POSTAL_CODE 
                 MAILING_COUNTRY_CODE MAILING_COUNTRY_NAME RESIDENCE_COUNTRY_CODE 
                 RESIDENCE_COUNTRY_NAME CITIZENSHIP_COUNTRY_CODE 
                 CITIZENSHIP_COUNTRY_NAME ORG_COUNTRY_OF_BUSINESS_CODE 
                 ORG_COUNTRY_OF_BUSINESS_NAME EMPLOYEE_IND EMPLOYEE_NUMBER 
                 EMPLOYER_NAME EMPLOYER_PHONE_NUMBER EMAIL_ADDRESS OCCUPATION_DESC 
                 INDUSTRY_CODE INDUSTRY_DESC PHONE_NUMBER_1 PHONE_NUMBER_2 
                 PHONE_NUMBER_3 ANNUAL_INCOME_AMOUNT NET_WORTH_AMOUNT 
                 MARITAL_STATUS_DESC LAST_CONTACT_DATE POLITICALLY_EXPOSED_PERSON_IND 
                 NON_PROFIT_ORG_IND CUSTOMER_SINCE_DATE LAST_SUSP_ACTV_RPT_DATE 
                 LAST_CASH_TRANS_RPT_DATE LAST_RISK_ASSESSMENT_DATE RISK_CLASSIFICATION 
                 CHANGE_BEGIN_DATE CHANGE_END_DATE CHANGE_CURRENT_IND VALID_FROM_DTTM )
      ; 
   
   attrib PARTY_KEY length=8 format=13. label="PARTY_KEY"
          SEGMENT_ID length=$128 format=$128. label="SEGMENT_ID"
          PARTY_NUMBER length=$50 format=$50. label="PARTY_NUMBER"
          PARTY_TYPE_DESC length=$20 format=$20. label="PARTY_TYPE_DESC"
          PARTY_TAX_ID length=$35 format=$35. label="PARTY_TAX_ID"
          PARTY_TAX_ID_TYPE_CODE length=$1 format=$1. label="PARTY_TAX_ID_TYPE_CODE"
          PARTY_IDENTIFICATION_ID length=$35 format=$35. label="PARTY_IDENTIFICATION_ID"
          PARTY_IDENTIFICATION_TYPE_DESC length=$4 format=$4. label="PARTY_IDENTIFICATION_TYPE_DESC"
          PARTY_ID_STATE_CODE length=$3 format=$3. label="PARTY_ID_STATE_CODE"
          PARTY_DATE_OF_BIRTH length=8 format=DATETIME20. label="PARTY_DATE_OF_BIRTH"
          PARTY_FIRST_NAME length=$50 format=$50. label="PARTY_FIRST_NAME"
          PARTY_LAST_NAME length=$50 format=$50. label="PARTY_LAST_NAME"
          PARTY_MIDDLE_NAME length=$100 format=$100. label="PARTY_MIDDLE_NAME"
          PARTY_NAME length=$200 format=$200. label="PARTY_NAME"
          DOING_BUSINESS_AS_NAME length=$35 format=$35. label="DOING_BUSINESS_AS_NAME"
          PARTY_STATUS_DESC length=$20 format=$20. label="PARTY_STATUS_DESC"
          ULTIMATE_PARENT_NAME length=$35 format=$35. label="ULTIMATE_PARENT_NAME"
          MATCH_CODE_ORGANIZATION length=$80 format=$80. label="MATCH_CODE_ORGANIZATION"
          MATCH_CODE_INDIVIDUAL length=$80 format=$80. label="MATCH_CODE_INDIVIDUAL"
          MATCH_CODE_STREET_ADDRESS length=$80 format=$80. label="MATCH_CODE_STREET_ADDRESS"
          MATCH_CODE_MAILING_ADDRESS length=$80 format=$80. label="MATCH_CODE_MAILING_ADDRESS"
          STREET_ADDRESS_1 length=$35 format=$35. label="STREET_ADDRESS_1"
          STREET_ADDRESS_2 length=$35 format=$35. label="STREET_ADDRESS_2"
          STREET_CITY_NAME length=$35 format=$35. label="STREET_CITY_NAME"
          STREET_STATE_CODE length=$3 format=$3. label="STREET_STATE_CODE"
          STREET_STATE_NAME length=$35 format=$35. label="STREET_STATE_NAME"
          STREET_POSTAL_CODE length=$10 format=$10. label="STREET_POSTAL_CODE"
          STREET_COUNTRY_CODE length=$3 format=$3. label="STREET_COUNTRY_CODE"
          STREET_COUNTRY_NAME length=$100 format=$100. label="STREET_COUNTRY_NAME"
          MAILING_ADDRESS_1 length=$35 format=$35. label="MAILING_ADDRESS_1"
          MAILING_ADDRESS_2 length=$35 format=$35. label="MAILING_ADDRESS_2"
          MAILING_CITY_NAME length=$35 format=$35. label="MAILING_CITY_NAME"
          MAILING_STATE_CODE length=$3 format=$3. label="MAILING_STATE_CODE"
          MAILING_STATE_NAME length=$35 format=$35. label="MAILING_STATE_NAME"
          MAILING_POSTAL_CODE length=$10 format=$10. label="MAILING_POSTAL_CODE"
          MAILING_COUNTRY_CODE length=$3 format=$3. label="MAILING_COUNTRY_CODE"
          MAILING_COUNTRY_NAME length=$100 format=$100. label="MAILING_COUNTRY_NAME"
          RESIDENCE_COUNTRY_CODE length=$3 format=$3. label="RESIDENCE_COUNTRY_CODE"
          RESIDENCE_COUNTRY_NAME length=$100 format=$100. label="RESIDENCE_COUNTRY_NAME"
          CITIZENSHIP_COUNTRY_CODE length=$3 format=$3. label="CITIZENSHIP_COUNTRY_CODE"
          CITIZENSHIP_COUNTRY_NAME length=$100 format=$100. label="CITIZENSHIP_COUNTRY_NAME"
          ORG_COUNTRY_OF_BUSINESS_CODE length=$3 format=$3. label="ORG_COUNTRY_OF_BUSINESS_CODE"
          ORG_COUNTRY_OF_BUSINESS_NAME length=$100 format=$100. label="ORG_COUNTRY_OF_BUSINESS_NAME"
          EMPLOYEE_IND length=$1 format=$1. label="EMPLOYEE_IND"
          EMPLOYEE_NUMBER length=$20 format=$20. label="EMPLOYEE_NUMBER"
          EMPLOYER_NAME length=$35 format=$35. label="EMPLOYER_NAME"
          EMPLOYER_PHONE_NUMBER length=$25 format=$25. label="EMPLOYER_PHONE_NUMBER"
          EMAIL_ADDRESS length=$35 format=$35. label="EMAIL_ADDRESS"
          OCCUPATION_DESC length=$35 format=$35. label="OCCUPATION_DESC"
          INDUSTRY_CODE length=$10 format=$10. label="INDUSTRY_CODE"
          INDUSTRY_DESC length=$255 format=$255. label="INDUSTRY_DESC"
          PHONE_NUMBER_1 length=$25 format=$25. label="PHONE_NUMBER_1"
          PHONE_NUMBER_2 length=$25 format=$25. label="PHONE_NUMBER_2"
          PHONE_NUMBER_3 length=$25 format=$25. label="PHONE_NUMBER_3"
          ANNUAL_INCOME_AMOUNT length=8 format=11. label="ANNUAL_INCOME_AMOUNT"
          NET_WORTH_AMOUNT length=8 format=11. label="NET_WORTH_AMOUNT"
          MARITAL_STATUS_DESC length=$20 format=$20. label="MARITAL_STATUS_DESC"
          LAST_CONTACT_DATE length=8 format=DATETIME20. label="LAST_CONTACT_DATE"
          POLITICALLY_EXPOSED_PERSON_IND length=$1 format=$1. label="POLITICALLY_EXPOSED_PERSON_IND"
          NON_PROFIT_ORG_IND length=$1 format=$1. label="NON_PROFIT_ORG_IND"
          CUSTOMER_SINCE_DATE length=8 format=DATETIME20. label="CUSTOMER_SINCE_DATE"
          LAST_SUSP_ACTV_RPT_DATE length=8 format=DATETIME20. label="LAST_SUSP_ACTV_RPT_DATE"
          LAST_CASH_TRANS_RPT_DATE length=8 format=DATETIME20. label="LAST_CASH_TRANS_RPT_DATE"
          LAST_RISK_ASSESSMENT_DATE length=8 format=DATETIME20. label="LAST_RISK_ASSESSMENT_DATE"
          RISK_CLASSIFICATION length=8 format=2. label="RISK_CLASSIFICATION"
          CHANGE_BEGIN_DATE length=8 format=DATETIME20. label="CHANGE_BEGIN_DATE"
          CHANGE_END_DATE length=8 format=DATETIME20. label="CHANGE_END_DATE"
          CHANGE_CURRENT_IND length=$1 format=$1. label="CHANGE_CURRENT_IND"
          ; 
   
   retain missing0-missing0 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table &db_core_libname..FSC_PARTY_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_PARTY_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "&db_core_libname..FSC_PARTY_DIM", hashexp: exponent);
            h0.defineKey( "PARTY_KEY");
            h0.defineData( "PARTY_KEY",
                           "SEGMENT_ID",
                           "PARTY_NUMBER",
                           "PARTY_TYPE_DESC",
                           "PARTY_TAX_ID",
                           "PARTY_TAX_ID_TYPE_CODE",
                           "PARTY_IDENTIFICATION_ID",
                           "PARTY_IDENTIFICATION_TYPE_DESC",
                           "PARTY_ID_STATE_CODE",
                           "PARTY_DATE_OF_BIRTH",
                           "PARTY_FIRST_NAME",
                           "PARTY_LAST_NAME",
                           "PARTY_MIDDLE_NAME",
                           "PARTY_NAME",
                           "DOING_BUSINESS_AS_NAME",
                           "PARTY_STATUS_DESC",
                           "ULTIMATE_PARENT_NAME",
                           "MATCH_CODE_ORGANIZATION",
                           "MATCH_CODE_INDIVIDUAL",
                           "MATCH_CODE_STREET_ADDRESS",
                           "MATCH_CODE_MAILING_ADDRESS",
                           "STREET_ADDRESS_1",
                           "STREET_ADDRESS_2",
                           "STREET_CITY_NAME",
                           "STREET_STATE_CODE",
                           "STREET_STATE_NAME",
                           "STREET_POSTAL_CODE",
                           "STREET_COUNTRY_CODE",
                           "STREET_COUNTRY_NAME",
                           "MAILING_ADDRESS_1",
                           "MAILING_ADDRESS_2",
                           "MAILING_CITY_NAME",
                           "MAILING_STATE_CODE",
                           "MAILING_STATE_NAME",
                           "MAILING_POSTAL_CODE",
                           "MAILING_COUNTRY_CODE",
                           "MAILING_COUNTRY_NAME",
                           "RESIDENCE_COUNTRY_CODE",
                           "RESIDENCE_COUNTRY_NAME",
                           "CITIZENSHIP_COUNTRY_CODE",
                           "CITIZENSHIP_COUNTRY_NAME",
                           "ORG_COUNTRY_OF_BUSINESS_CODE",
                           "ORG_COUNTRY_OF_BUSINESS_NAME",
                           "EMPLOYEE_IND",
                           "EMPLOYEE_NUMBER",
                           "EMPLOYER_NAME",
                           "EMPLOYER_PHONE_NUMBER",
                           "EMAIL_ADDRESS",
                           "OCCUPATION_DESC",
                           "INDUSTRY_CODE",
                           "INDUSTRY_DESC",
                           "PHONE_NUMBER_1",
                           "PHONE_NUMBER_2",
                           "PHONE_NUMBER_3",
                           "ANNUAL_INCOME_AMOUNT",
                           "NET_WORTH_AMOUNT",
                           "MARITAL_STATUS_DESC",
                           "LAST_CONTACT_DATE",
                           "POLITICALLY_EXPOSED_PERSON_IND",
                           "NON_PROFIT_ORG_IND",
                           "CUSTOMER_SINCE_DATE",
                           "LAST_SUSP_ACTV_RPT_DATE",
                           "LAST_CASH_TRANS_RPT_DATE",
                           "CHANGE_BEGIN_DATE",
                           "CHANGE_END_DATE",
                           "CHANGE_CURRENT_IND");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_PARTY_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_PARTY_DIM";
                  
                  abort 4; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_PARTY_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_PARTY_DIM";
            
            abort 4; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_PARTY_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_PARTY_DIM";
         
         abort 4; 
      end; 
      
      call missing (PARTY_KEY, SEGMENT_ID, PARTY_NUMBER, PARTY_TYPE_DESC, 
                    PARTY_TAX_ID, PARTY_TAX_ID_TYPE_CODE, PARTY_IDENTIFICATION_ID, 
                    PARTY_IDENTIFICATION_TYPE_DESC, PARTY_ID_STATE_CODE, 
                    PARTY_DATE_OF_BIRTH, PARTY_FIRST_NAME, PARTY_LAST_NAME, 
                    PARTY_MIDDLE_NAME, PARTY_NAME, DOING_BUSINESS_AS_NAME, 
                    PARTY_STATUS_DESC, ULTIMATE_PARENT_NAME, MATCH_CODE_ORGANIZATION, 
                    MATCH_CODE_INDIVIDUAL, MATCH_CODE_STREET_ADDRESS, 
                    MATCH_CODE_MAILING_ADDRESS, STREET_ADDRESS_1, STREET_ADDRESS_2, 
                    STREET_CITY_NAME, STREET_STATE_CODE, STREET_STATE_NAME, 
                    STREET_POSTAL_CODE, STREET_COUNTRY_CODE, STREET_COUNTRY_NAME, 
                    MAILING_ADDRESS_1, MAILING_ADDRESS_2, MAILING_CITY_NAME, 
                    MAILING_STATE_CODE, MAILING_STATE_NAME, MAILING_POSTAL_CODE, 
                    MAILING_COUNTRY_CODE, MAILING_COUNTRY_NAME, 
                    RESIDENCE_COUNTRY_CODE, RESIDENCE_COUNTRY_NAME, 
                    CITIZENSHIP_COUNTRY_CODE, CITIZENSHIP_COUNTRY_NAME, 
                    ORG_COUNTRY_OF_BUSINESS_CODE, ORG_COUNTRY_OF_BUSINESS_NAME, 
                    EMPLOYEE_IND, EMPLOYEE_NUMBER, EMPLOYER_NAME, 
                    EMPLOYER_PHONE_NUMBER, EMAIL_ADDRESS, OCCUPATION_DESC, 
                    INDUSTRY_CODE, INDUSTRY_DESC, PHONE_NUMBER_1, PHONE_NUMBER_2, 
                    PHONE_NUMBER_3, ANNUAL_INCOME_AMOUNT, NET_WORTH_AMOUNT, 
                    MARITAL_STATUS_DESC, LAST_CONTACT_DATE, 
                    POLITICALLY_EXPOSED_PERSON_IND, NON_PROFIT_ORG_IND, 
                    CUSTOMER_SINCE_DATE, LAST_SUSP_ACTV_RPT_DATE, 
                    LAST_CASH_TRANS_RPT_DATE, CHANGE_BEGIN_DATE, CHANGE_END_DATE, 
                    CHANGE_CURRENT_IND); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W68RIBZD end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: PARTY_key);
   /* Examine success of lookups  */ 
   if ( rc0=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W8AJ77XO; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Abort  */ 
         abort 4; 
      end; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 


proc datasets lib = work nolist nowarn memtype = (data view);
   delete WDHK98OG;
quit;

proc sql;
   create table work.WDHK98OG as
      select
         PARTY_KEY,
         SEGMENT_ID,
         PARTY_NUMBER,
         PARTY_TYPE_DESC,
         PARTY_TAX_ID,
         PARTY_TAX_ID_TYPE_CODE,
         PARTY_IDENTIFICATION_ID,
         PARTY_IDENTIFICATION_TYPE_DESC,
         PARTY_ID_STATE_CODE,
         PARTY_DATE_OF_BIRTH,
         PARTY_FIRST_NAME,
         PARTY_LAST_NAME,
         PARTY_MIDDLE_NAME,
         PARTY_NAME,
         DOING_BUSINESS_AS_NAME,
         PARTY_STATUS_DESC,
         ULTIMATE_PARENT_NAME,
         MATCH_CODE_ORGANIZATION,
         MATCH_CODE_INDIVIDUAL,
         MATCH_CODE_STREET_ADDRESS,
         MATCH_CODE_MAILING_ADDRESS,
         STREET_ADDRESS_1,
         STREET_ADDRESS_2,
         STREET_CITY_NAME,
         STREET_STATE_CODE,
         STREET_STATE_NAME,
         STREET_POSTAL_CODE,
         STREET_COUNTRY_CODE,
         STREET_COUNTRY_NAME,
         MAILING_ADDRESS_1,
         MAILING_ADDRESS_2,
         MAILING_CITY_NAME,
         MAILING_STATE_CODE,
         MAILING_STATE_NAME,
         MAILING_POSTAL_CODE,
         MAILING_COUNTRY_CODE,
         MAILING_COUNTRY_NAME,
         RESIDENCE_COUNTRY_CODE,
         RESIDENCE_COUNTRY_NAME,
         CITIZENSHIP_COUNTRY_CODE,
         CITIZENSHIP_COUNTRY_NAME,
         ORG_COUNTRY_OF_BUSINESS_CODE,
         ORG_COUNTRY_OF_BUSINESS_NAME,
         EMPLOYEE_IND,
         EMPLOYEE_NUMBER,
         EMPLOYER_NAME,
         EMPLOYER_PHONE_NUMBER,
         EMAIL_ADDRESS,
         OCCUPATION_DESC,
         INDUSTRY_CODE,
         INDUSTRY_DESC,
         PHONE_NUMBER_1,
         PHONE_NUMBER_2,
         PHONE_NUMBER_3,
         ANNUAL_INCOME_AMOUNT,
         NET_WORTH_AMOUNT,
         MARITAL_STATUS_DESC,
         LAST_CONTACT_DATE,
         POLITICALLY_EXPOSED_PERSON_IND,
         NON_PROFIT_ORG_IND,
         CUSTOMER_SINCE_DATE,
         LAST_SUSP_ACTV_RPT_DATE,
         LAST_CASH_TRANS_RPT_DATE,
         VALID_FROM_DTTM as LAST_RISK_ASSESSMENT_DATE   
            format = DATETIME20.
            informat = DATETIME20.
            label = 'LAST_RISK_ASSESSMENT_DATE',
         RISK_CLASSIFICATION   
            format = 2.
            informat = 2.
            label = 'RISK_CLASSIFICATION',
         CHANGE_BEGIN_DATE,
         CHANGE_END_DATE,
         CHANGE_CURRENT_IND
   from work.W8AJ77XO
   ;
quit;

%let SOURCEDS = work.WDHK98OG;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8AJ77XO;
quit;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV00032P * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.WDHK98OG                A5DG55RP.BR0001Z6 * 
 * Target Table:    New Party Updates -                   A5DG55RP.BH0001BH * 
 *                   iem.new_party_updates                                  * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.WDHK98OG); 

data _null_;
  call symput('current_dt',put(datetime(),datetime22.));
run;

proc sql;
      create view work.W8AJ7844 as
         select
            PARTY_KEY,
            SEGMENT_ID,
            PARTY_NUMBER,
            PARTY_TYPE_DESC,
            PARTY_TAX_ID,
            PARTY_TAX_ID_TYPE_CODE,
            PARTY_IDENTIFICATION_ID,
            PARTY_IDENTIFICATION_TYPE_DESC,
            PARTY_ID_STATE_CODE,
            PARTY_DATE_OF_BIRTH,
            PARTY_FIRST_NAME,
            PARTY_LAST_NAME,
            PARTY_MIDDLE_NAME,
            PARTY_NAME,
            DOING_BUSINESS_AS_NAME,
            PARTY_STATUS_DESC,
            ULTIMATE_PARENT_NAME,
            MATCH_CODE_ORGANIZATION,
            MATCH_CODE_INDIVIDUAL,
            MATCH_CODE_STREET_ADDRESS,
            MATCH_CODE_MAILING_ADDRESS,
            STREET_ADDRESS_1,
            STREET_ADDRESS_2,
            STREET_CITY_NAME,
            STREET_STATE_CODE,
            STREET_STATE_NAME,
            STREET_POSTAL_CODE,
            STREET_COUNTRY_CODE,
            STREET_COUNTRY_NAME,
            MAILING_ADDRESS_1,
            MAILING_ADDRESS_2,
            MAILING_CITY_NAME,
            MAILING_STATE_CODE,
            MAILING_STATE_NAME,
            MAILING_POSTAL_CODE,
            MAILING_COUNTRY_CODE,
            MAILING_COUNTRY_NAME,
            RESIDENCE_COUNTRY_CODE,
            RESIDENCE_COUNTRY_NAME,
            CITIZENSHIP_COUNTRY_CODE,
            CITIZENSHIP_COUNTRY_NAME,
            ORG_COUNTRY_OF_BUSINESS_CODE,
            ORG_COUNTRY_OF_BUSINESS_NAME,
            EMPLOYEE_IND,
            EMPLOYEE_NUMBER,
            EMPLOYER_NAME,
            EMPLOYER_PHONE_NUMBER,
            EMAIL_ADDRESS,
            OCCUPATION_DESC,
            INDUSTRY_CODE,
            INDUSTRY_DESC,
            PHONE_NUMBER_1,
            PHONE_NUMBER_2,
            PHONE_NUMBER_3,
            ANNUAL_INCOME_AMOUNT,
            NET_WORTH_AMOUNT,
            MARITAL_STATUS_DESC,
            LAST_CONTACT_DATE,
            POLITICALLY_EXPOSED_PERSON_IND,
            NON_PROFIT_ORG_IND,
            CUSTOMER_SINCE_DATE,
            LAST_SUSP_ACTV_RPT_DATE,
            LAST_CASH_TRANS_RPT_DATE,
            LAST_RISK_ASSESSMENT_DATE,
            RISK_CLASSIFICATION,
            CHANGE_BEGIN_DATE,
            ("&current_dt"dt) as CHANGE_END_DATE length = 8
               format = DATETIME20.
               informat = DATETIME20.,
            CHANGE_CURRENT_IND,
            . as NEW_PARTY_KEY length = 8
               format = 13.
               informat = 13.,
            ("&current_dt"dt + 1) as NEW_CHANGE_BEGIN_DATE length = 8
               format = DATETIME20.
               informat = DATETIME20.,
            CHANGE_END_DATE as NEW_CHANGE_END_DATE
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W8AJ7844;

proc datasets lib = iem nolist nowarn memtype = (data view);
	delete new_party_updates;
quit;
      
data iem.new_party_updates;
  attrib PARTY_KEY length = 8
     format = 13.
     informat = 13.
     label = 'PARTY_KEY'; 
  attrib SEGMENT_ID length = $128
     format = $128.
     informat = $128.
     label = 'SEGMENT_ID'; 
  attrib PARTY_NUMBER length = $50
     format = $50.
     informat = $50.
     label = 'PARTY_NUMBER'; 
  attrib PARTY_TYPE_DESC length = $20
     format = $20.
     informat = $20.
     label = 'PARTY_TYPE_DESC'; 
  attrib PARTY_TAX_ID length = $35
     format = $35.
     informat = $35.
     label = 'PARTY_TAX_ID'; 
  attrib PARTY_TAX_ID_TYPE_CODE length = $1
     format = $1.
     informat = $1.
     label = 'PARTY_TAX_ID_TYPE_CODE'; 
  attrib PARTY_IDENTIFICATION_ID length = $35
     format = $35.
     informat = $35.
     label = 'PARTY_IDENTIFICATION_ID'; 
  attrib PARTY_IDENTIFICATION_TYPE_DESC length = $4
     format = $4.
     informat = $4.
     label = 'PARTY_IDENTIFICATION_TYPE_DESC'; 
  attrib PARTY_ID_STATE_CODE length = $3
     format = $3.
     informat = $3.
     label = 'PARTY_ID_STATE_CODE'; 
  attrib PARTY_DATE_OF_BIRTH length = 8
     format = DATETIME20.
     informat = DATETIME20.
     label = 'PARTY_DATE_OF_BIRTH'; 
  attrib PARTY_FIRST_NAME length = $50
     format = $50.
     informat = $50.
     label = 'PARTY_FIRST_NAME'; 
  attrib PARTY_LAST_NAME length = $50
     format = $50.
     informat = $50.
     label = 'PARTY_LAST_NAME'; 
  attrib PARTY_MIDDLE_NAME length = $100
     format = $100.
     informat = $100.
     label = 'PARTY_MIDDLE_NAME'; 
  attrib PARTY_NAME length = $200
     format = $200.
     informat = $200.
     label = 'PARTY_NAME'; 
  attrib DOING_BUSINESS_AS_NAME length = $35
     format = $35.
     informat = $35.
     label = 'DOING_BUSINESS_AS_NAME'; 
  attrib PARTY_STATUS_DESC length = $20
     format = $20.
     informat = $20.
     label = 'PARTY_STATUS_DESC'; 
  attrib ULTIMATE_PARENT_NAME length = $35
     format = $35.
     informat = $35.
     label = 'ULTIMATE_PARENT_NAME'; 
  attrib MATCH_CODE_ORGANIZATION length = $80
     format = $80.
     informat = $80.
     label = 'MATCH_CODE_ORGANIZATION'; 
  attrib MATCH_CODE_INDIVIDUAL length = $80
     format = $80.
     informat = $80.
     label = 'MATCH_CODE_INDIVIDUAL'; 
  attrib MATCH_CODE_STREET_ADDRESS length = $80
     format = $80.
     informat = $80.
     label = 'MATCH_CODE_STREET_ADDRESS'; 
  attrib MATCH_CODE_MAILING_ADDRESS length = $80
     format = $80.
     informat = $80.
     label = 'MATCH_CODE_MAILING_ADDRESS'; 
  attrib STREET_ADDRESS_1 length = $35
     format = $35.
     informat = $35.
     label = 'STREET_ADDRESS_1'; 
  attrib STREET_ADDRESS_2 length = $35
     format = $35.
     informat = $35.
     label = 'STREET_ADDRESS_2'; 
  attrib STREET_CITY_NAME length = $35
     format = $35.
     informat = $35.
     label = 'STREET_CITY_NAME'; 
  attrib STREET_STATE_CODE length = $3
     format = $3.
     informat = $3.
     label = 'STREET_STATE_CODE'; 
  attrib STREET_STATE_NAME length = $35
     format = $35.
     informat = $35.
     label = 'STREET_STATE_NAME'; 
  attrib STREET_POSTAL_CODE length = $10
     format = $10.
     informat = $10.
     label = 'STREET_POSTAL_CODE'; 
  attrib STREET_COUNTRY_CODE length = $3
     format = $3.
     informat = $3.
     label = 'STREET_COUNTRY_CODE'; 
  attrib STREET_COUNTRY_NAME length = $100
     format = $100.
     informat = $100.
     label = 'STREET_COUNTRY_NAME'; 
  attrib MAILING_ADDRESS_1 length = $35
     format = $35.
     informat = $35.
     label = 'MAILING_ADDRESS_1'; 
  attrib MAILING_ADDRESS_2 length = $35
     format = $35.
     informat = $35.
     label = 'MAILING_ADDRESS_2'; 
  attrib MAILING_CITY_NAME length = $35
     format = $35.
     informat = $35.
     label = 'MAILING_CITY_NAME'; 
  attrib MAILING_STATE_CODE length = $3
     format = $3.
     informat = $3.
     label = 'MAILING_STATE_CODE'; 
  attrib MAILING_STATE_NAME length = $35
     format = $35.
     informat = $35.
     label = 'MAILING_STATE_NAME'; 
  attrib MAILING_POSTAL_CODE length = $10
     format = $10.
     informat = $10.
     label = 'MAILING_POSTAL_CODE'; 
  attrib MAILING_COUNTRY_CODE length = $3
     format = $3.
     informat = $3.
     label = 'MAILING_COUNTRY_CODE'; 
  attrib MAILING_COUNTRY_NAME length = $100
     format = $100.
     informat = $100.
     label = 'MAILING_COUNTRY_NAME'; 
  attrib RESIDENCE_COUNTRY_CODE length = $3
     format = $3.
     informat = $3.
     label = 'RESIDENCE_COUNTRY_CODE'; 
  attrib RESIDENCE_COUNTRY_NAME length = $100
     format = $100.
     informat = $100.
     label = 'RESIDENCE_COUNTRY_NAME'; 
  attrib CITIZENSHIP_COUNTRY_CODE length = $3
     format = $3.
     informat = $3.
     label = 'CITIZENSHIP_COUNTRY_CODE'; 
  attrib CITIZENSHIP_COUNTRY_NAME length = $100
     format = $100.
     informat = $100.
     label = 'CITIZENSHIP_COUNTRY_NAME'; 
  attrib ORG_COUNTRY_OF_BUSINESS_CODE length = $3
     format = $3.
     informat = $3.
     label = 'ORG_COUNTRY_OF_BUSINESS_CODE'; 
  attrib ORG_COUNTRY_OF_BUSINESS_NAME length = $100
     format = $100.
     informat = $100.
     label = 'ORG_COUNTRY_OF_BUSINESS_NAME'; 
  attrib EMPLOYEE_IND length = $1
     format = $1.
     informat = $1.
     label = 'EMPLOYEE_IND'; 
  attrib EMPLOYEE_NUMBER length = $20
     format = $20.
     informat = $20.
     label = 'EMPLOYEE_NUMBER'; 
  attrib EMPLOYER_NAME length = $35
     format = $35.
     informat = $35.
     label = 'EMPLOYER_NAME'; 
  attrib EMPLOYER_PHONE_NUMBER length = $25
     format = $25.
     informat = $25.
     label = 'EMPLOYER_PHONE_NUMBER'; 
  attrib EMAIL_ADDRESS length = $35
     format = $35.
     informat = $35.
     label = 'EMAIL_ADDRESS'; 
  attrib OCCUPATION_DESC length = $35
     format = $35.
     informat = $35.
     label = 'OCCUPATION_DESC'; 
  attrib INDUSTRY_CODE length = $10
     format = $10.
     informat = $10.
     label = 'INDUSTRY_CODE'; 
  attrib INDUSTRY_DESC length = $255
     format = $255.
     informat = $255.
     label = 'INDUSTRY_DESC'; 
  attrib PHONE_NUMBER_1 length = $25
     format = $25.
     informat = $25.
     label = 'PHONE_NUMBER_1'; 
  attrib PHONE_NUMBER_2 length = $25
     format = $25.
     informat = $25.
     label = 'PHONE_NUMBER_2'; 
  attrib PHONE_NUMBER_3 length = $25
     format = $25.
     informat = $25.
     label = 'PHONE_NUMBER_3'; 
  attrib ANNUAL_INCOME_AMOUNT length = 8
     format = 11.
     informat = 11.
     label = 'ANNUAL_INCOME_AMOUNT'; 
  attrib NET_WORTH_AMOUNT length = 8
     format = 11.
     informat = 11.
     label = 'NET_WORTH_AMOUNT'; 
  attrib MARITAL_STATUS_DESC length = $20
     format = $20.
     informat = $20.
     label = 'MARITAL_STATUS_DESC'; 
  attrib LAST_CONTACT_DATE length = 8
     format = DATETIME20.
     informat = DATETIME20.
     label = 'LAST_CONTACT_DATE'; 
  attrib POLITICALLY_EXPOSED_PERSON_IND length = $1
     format = $1.
     informat = $1.
     label = 'POLITICALLY_EXPOSED_PERSON_IND'; 
  attrib NON_PROFIT_ORG_IND length = $1
     format = $1.
     informat = $1.
     label = 'NON_PROFIT_ORG_IND'; 
  attrib CUSTOMER_SINCE_DATE length = 8
     format = DATETIME20.
     informat = DATETIME20.
     label = 'CUSTOMER_SINCE_DATE'; 
  attrib LAST_SUSP_ACTV_RPT_DATE length = 8
     format = DATETIME20.
     informat = DATETIME20.
     label = 'LAST_SUSP_ACTV_RPT_DATE'; 
  attrib LAST_CASH_TRANS_RPT_DATE length = 8
     format = DATETIME20.
     informat = DATETIME20.
     label = 'LAST_CASH_TRANS_RPT_DATE'; 
  attrib LAST_RISK_ASSESSMENT_DATE length = 8
     format = DATETIME20.
     informat = DATETIME20.
     label = 'LAST_RISK_ASSESSMENT_DATE'; 
  attrib RISK_CLASSIFICATION length = 8
     format = 2.
     informat = 2.
     label = 'RISK_CLASSIFICATION'; 
  attrib CHANGE_BEGIN_DATE length = 8
     format = DATETIME20.
     informat = DATETIME20.
     label = 'CHANGE_BEGIN_DATE'; 
  attrib CHANGE_END_DATE length = 8
     format = DATETIME20.
     informat = DATETIME20.
     label = 'CHANGE_END_DATE'; 
  attrib CHANGE_CURRENT_IND length = $1
     format = $1.
     informat = $1.
     label = 'CHANGE_CURRENT_IND'; 
  attrib NEW_PARTY_KEY length = 8
     format = 13.
     informat = 13.; 
  attrib NEW_CHANGE_BEGIN_DATE length = 8
     format = DATETIME20.
     informat = DATETIME20.; 
  attrib NEW_CHANGE_END_DATE length = 8
     format = DATETIME20.
     informat = DATETIME20.; 
  call missing(of _all_);
  stop;
run;
   
proc append base = iem.new_party_updates 
   data = &SOURCEDS  force ; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8AJ7844;
quit;

%let obs_count = %fcf_get_observation_count(table=iem.new_party_updates, SASDATASET=Y);
%let numevents = &obs_count;

%fcf_get_sequence_ids(numIDs=&numevents);

data iem.new_party_updates;
	attrib new_party_key informat=best32. format=best32. label='new_party_key';
	set iem.new_party_updates;
	new_party_key = symgetn('seqId'||(kstrip(put(_n_,best32.))));
run;

/*==========================================================================* 
 * Step:            Update                                A5DG55RP.BV00032X * 
 * Transform:       Update                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Party Updates -                   A5DG55RP.BH0001BH * 
 *                   iem.new_party_updates                                  * 
 * Target Table:    FSC_PARTY_DIM -                                         *
 *                   &db_core_libname..FSC_PARTY_DIM  A5DG55RP.BH00019F     * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.new_party_updates); 

/*---- Update the target table  ----*/ 
proc sql;
   update &db_core_libname..FSC_PARTY_DIM
      set 
         CHANGE_END_DATE= (
            select
               new_party_updates.CHANGE_END_DATE length = 8   
                  format = DATETIME20.
                  informat = DATETIME20.
                  label = 'CHANGE_END_DATE'
            from
               iem.new_party_updates as new_party_updates
            where
               FSC_PARTY_DIM.PARTY_KEY = new_party_updates.PARTY_KEY
         ),
         CHANGE_CURRENT_IND= 'N'
      where
         PARTY_KEY IN (
            select
               new_party_updates.PARTY_KEY length = 8   
                  format = 13.
                  informat = 13.
                  label = 'PARTY_KEY'
            from
               iem.new_party_updates as new_party_updates
         )
         and CHANGE_CURRENT_IND = 'Y'
   ;
quit;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV00032Y * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Party Updates -                   A5DG55RP.BH0001BH * 
 *                   iem.new_party_updates                                  * 
 * Target Table:    FSC_PARTY_DIM -											*
 *                   &db_core_libname..FSC_PARTY_DIM  A5DG55RP.BH00019F     * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.new_party_updates); 

proc datasets lib = work nolist nowarn memtype = (data view);
      delete W8AJ78GY;
   quit;

proc sql;
  create view work.W8AJ78GY as
     select
        NEW_PARTY_KEY as PARTY_KEY,
        SEGMENT_ID,
        PARTY_NUMBER,
        PARTY_TYPE_DESC,
        PARTY_TAX_ID,
        PARTY_TAX_ID_TYPE_CODE,
        PARTY_IDENTIFICATION_ID,
        PARTY_IDENTIFICATION_TYPE_DESC,
        PARTY_ID_STATE_CODE,
        PARTY_DATE_OF_BIRTH,
        PARTY_FIRST_NAME,
        PARTY_LAST_NAME,
        PARTY_MIDDLE_NAME,
        PARTY_NAME,
        DOING_BUSINESS_AS_NAME,
        PARTY_STATUS_DESC,
        ULTIMATE_PARENT_NAME,
        MATCH_CODE_ORGANIZATION,
        MATCH_CODE_INDIVIDUAL,
        MATCH_CODE_STREET_ADDRESS,
        MATCH_CODE_MAILING_ADDRESS,
        STREET_ADDRESS_1,
        STREET_ADDRESS_2,
        STREET_CITY_NAME,
        STREET_STATE_CODE,
        STREET_STATE_NAME,
        STREET_POSTAL_CODE,
        STREET_COUNTRY_CODE,
        STREET_COUNTRY_NAME,
        MAILING_ADDRESS_1,
        MAILING_ADDRESS_2,
        MAILING_CITY_NAME,
        MAILING_STATE_CODE,
        MAILING_STATE_NAME,
        MAILING_POSTAL_CODE,
        MAILING_COUNTRY_CODE,
        MAILING_COUNTRY_NAME,
        RESIDENCE_COUNTRY_CODE,
        RESIDENCE_COUNTRY_NAME,
        CITIZENSHIP_COUNTRY_CODE,
        CITIZENSHIP_COUNTRY_NAME,
        ORG_COUNTRY_OF_BUSINESS_CODE,
        ORG_COUNTRY_OF_BUSINESS_NAME,
        EMPLOYEE_IND,
        EMPLOYEE_NUMBER,
        EMPLOYER_NAME,
        EMPLOYER_PHONE_NUMBER,
        EMAIL_ADDRESS,
        OCCUPATION_DESC,
        INDUSTRY_CODE,
        INDUSTRY_DESC,
        PHONE_NUMBER_1,
        PHONE_NUMBER_2,
        PHONE_NUMBER_3,
        ANNUAL_INCOME_AMOUNT,
        NET_WORTH_AMOUNT,
        MARITAL_STATUS_DESC,
        LAST_CONTACT_DATE,
        POLITICALLY_EXPOSED_PERSON_IND,
        NON_PROFIT_ORG_IND,
        CUSTOMER_SINCE_DATE,
        LAST_SUSP_ACTV_RPT_DATE,
        LAST_CASH_TRANS_RPT_DATE,
        LAST_RISK_ASSESSMENT_DATE,
        RISK_CLASSIFICATION,
        NEW_CHANGE_BEGIN_DATE as CHANGE_BEGIN_DATE,
        NEW_CHANGE_END_DATE as CHANGE_END_DATE,
        CHANGE_CURRENT_IND
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W8AJ78GY;

proc append base = &db_core_libname..FSC_PARTY_DIM 
	data = &SOURCEDS force ; 
run; 

proc datasets lib = work nolist nowarn memtype = (data view);
	delete W8AJ78GY;
quit;


/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV00034I * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   New Party Updates -                   A5DG55RP.BH0001BH * 
 *                   iem.new_party_updates                                  * 
 *                  FSC_PARTY_ACCOUNT_BRIDGE -            A5DG55RP.BH00019E * 
 *                   &db_core_libname..FSC_PARTY_ACCOUNT_BRIDGE             * 
 * Target Table:    Lookup - work.W88X47XB                A5DG55RP.BR000203 * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete etls_temp_lookupview0;
quit;

proc sql; create view etls_temp_lookupview0 as 
   select * from &db_core_libname..FSC_PARTY_ACCOUNT_BRIDGE
   where CHANGE_CURRENT_IND = 'Y';
quit;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8AJ78IG;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.W8AJ78IG
         (keep = ACCOUNT_KEY PARTY_KEY ROLE_KEY CHANGE_BEGIN_DATE SEGMENT_ID ROLE_DESC 
                 CHANGE_END_DATE CHANGE_CURRENT_IND NEW_PARTY_KEY NEW_CHANGE_BEGIN_DATE 
                 NEW_CHANGE_END_DATE )
      ; 
   
   attrib ACCOUNT_KEY length=8 format=13. label="ACCOUNT_KEY"
          PARTY_KEY length=8 format=13. label="PARTY_KEY"
          ROLE_KEY length=8 format=3. label="ROLE_KEY"
          CHANGE_BEGIN_DATE length=8 format=DATETIME20. label="CHANGE_BEGIN_DATE"
          SEGMENT_ID length=$128 format=$128. label="SEGMENT_ID"
          ROLE_DESC length=$20 format=$20. label="ROLE_DESC"
          CHANGE_END_DATE length=8 format=DATETIME20. label="CHANGE_END_DATE"
          CHANGE_CURRENT_IND length=$1 format=$1. label="CHANGE_CURRENT_IND"
          NEW_PARTY_KEY length=8 format=13.
          NEW_CHANGE_BEGIN_DATE length=8 format=DATETIME20.
          NEW_CHANGE_END_DATE length=8 format=DATETIME20.
          ; 
   
   retain missing0-missing0 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table etls_temp_lookupview0 */ 
      nlobs = .; 
      dsid = open("etls_temp_lookupview0"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "etls_temp_lookupview0", hashexp: exponent);
            h0.defineKey( "PARTY_KEY");
            h0.defineData( "ACCOUNT_KEY",
                           "PARTY_KEY",
                           "ROLE_KEY",
                           "CHANGE_BEGIN_DATE",
                           "SEGMENT_ID",
                           "ROLE_DESC",
                           "CHANGE_CURRENT_IND",
                           "CHANGE_END_DATE");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: etls_temp_lookupview0";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " etls_temp_lookupview0";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: etls_temp_lookupview0";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " etls_temp_lookupview0";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " etls_temp_lookupview0";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " etls_temp_lookupview0";
         
         abort 3; 
      end; 
      
      call missing (PARTY_KEY, ACCOUNT_KEY, ROLE_KEY, CHANGE_BEGIN_DATE, SEGMENT_ID, 
                    ROLE_DESC, CHANGE_CURRENT_IND, CHANGE_END_DATE); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set iem.new_party_updates end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: PARTY_KEY);
   NEW_CHANGE_END_DATE = CHANGE_END_DATE;
   /* Examine success of lookups  */ 
   if ( rc0=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W8AJ78IG; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Skip the record  */ 
         return; 
      end; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

data _null_;
  call symput('current_dt',put(datetime(),datetime22.));
run;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W88X47XB;
quit;

proc sql;
   create table work.W88X47XB as
      select
         ACCOUNT_KEY,
         PARTY_KEY,
         ROLE_KEY,
         CHANGE_BEGIN_DATE,
         SEGMENT_ID,
         ROLE_DESC,
         ("&current_dt"dt) as CHANGE_END_DATE length = 8
            format = DATETIME20.
            informat = DATETIME20.
            label = 'CHANGE_END_DATE',
         CHANGE_CURRENT_IND,
         NEW_PARTY_KEY,
         ("&current_dt"dt + 1) as NEW_CHANGE_BEGIN_DATE length = 8
            format = DATETIME20.
            informat = DATETIME20.,
         NEW_CHANGE_END_DATE
   from work.W8AJ78IG
   ;
quit;

%let SOURCEDS = work.W88X47XB;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8AJ78IG;
quit;


/*==========================================================================* 
 * Step:            Update                                A5DG55RP.BV00034K * 
 * Transform:       Update                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W88X47XB                A5DG55RP.BR000203 * 
 * Target Table:    FSC_PARTY_ACCOUNT_BRIDGE -            A5DG55RP.BH00019E * 
 *                   &db_core_libname..FSC_PARTY_ACCOUNT_BRIDGE             *
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W88X47XB); 

/*---- Update the target table  ----*/ 
proc sql;
   update &db_core_libname..FSC_PARTY_ACCOUNT_BRIDGE
      set 
         CHANGE_END_DATE= (
            select
               W88X47XB.CHANGE_END_DATE length = 8   
                  format = DATETIME20.
                  informat = DATETIME20.
                  label = 'CHANGE_END_DATE'
            from
               work.W88X47XB as W88X47XB
            where
               FSC_PARTY_ACCOUNT_BRIDGE.ACCOUNT_KEY = W88X47XB.ACCOUNT_KEY
               and FSC_PARTY_ACCOUNT_BRIDGE.PARTY_KEY = W88X47XB.PARTY_KEY
         ),
         CHANGE_CURRENT_IND= 'N'
      where
         PARTY_KEY IN (
            select
               W88X47XB.PARTY_KEY length = 8   
                  format = 13.
                  informat = 13.
                  label = 'PARTY_KEY'
            from
               work.W88X47XB as W88X47XB
         )
         and CHANGE_CURRENT_IND = 'Y'
   ;
quit;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV00034M * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W88X47XB                A5DG55RP.BR000203 * 
 * Target Table:    FSC_PARTY_ACCOUNT_BRIDGE -            A5DG55RP.BH00019E * 
 *                   &db_core_libname..FSC_PARTY_ACCOUNT_BRIDGE             * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W88X47XB); 

proc datasets lib = work nolist nowarn memtype = (data view);
  delete W8AJ78TV;
quit;

proc sql;
  create view work.W8AJ78TV as
     select
        ACCOUNT_KEY,
        NEW_PARTY_KEY as PARTY_KEY,
        ROLE_KEY,
        NEW_CHANGE_BEGIN_DATE as CHANGE_BEGIN_DATE,
        SEGMENT_ID,
        ROLE_DESC,
        NEW_CHANGE_END_DATE as CHANGE_END_DATE,
        ('Y') as CHANGE_CURRENT_IND length = 1
           format = $1.
           informat = $1.
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W8AJ78TV;

proc append base = &db_core_libname..FSC_PARTY_ACCOUNT_BRIDGE 
  data = &SOURCEDS force ; 
run; 


proc datasets lib = work nolist nowarn memtype = (data view);
  delete W8AJ78TV;
quit;


/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV00034J * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   New Party Updates -                   A5DG55RP.BH0001BH * 
 *                   iem.new_party_updates                                  * 
 *                  FSC_HOUSEHOLD_PARTY_BRIDGE -          A5DG55RP.BH00019D * 
 *                   &db_core_libname..FSC_HOUSEHOLD_PARTY_BRIDGE           * 
 * Target Table:    Lookup - work.W88X4V5F                A5DG55RP.BR000204 * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete etls_temp_lookupview0;
quit;

proc sql; create view etls_temp_lookupview0 as 
   select * from &db_core_libname..FSC_HOUSEHOLD_PARTY_BRIDGE
   where CHANGE_CURRENT_IND = 'Y';
quit;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8EZW87U;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.W8EZW87U
         (keep = PARTY_KEY HOUSEHOLD_KEY CHANGE_BEGIN_DATE SEGMENT_ID CHANGE_END_DATE 
                 CHANGE_CURRENT_IND NEW_PARTY_KEY NEW_CHANGE_BEGIN_DATE 
                 NEW_CHANGE_END_DATE )
      ; 
   
   attrib PARTY_KEY length=8 format=13. label="PARTY_KEY"
          HOUSEHOLD_KEY length=8 format=13. label="HOUSEHOLD_KEY"
          CHANGE_BEGIN_DATE length=8 format=DATETIME20. label="CHANGE_BEGIN_DATE"
          SEGMENT_ID length=$128 format=$128. label="SEGMENT_ID"
          CHANGE_END_DATE length=8 format=DATETIME20. label="CHANGE_END_DATE"
          CHANGE_CURRENT_IND length=$1 format=$1. label="CHANGE_CURRENT_IND"
          NEW_PARTY_KEY length=8 format=13.
          NEW_CHANGE_BEGIN_DATE length=8 format=DATETIME20.
          NEW_CHANGE_END_DATE length=8 format=DATETIME20.
          ; 
   
   retain missing0-missing0 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table etls_temp_lookupview0 */ 
      nlobs = .; 
      dsid = open("etls_temp_lookupview0"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "etls_temp_lookupview0", hashexp: exponent);
            h0.defineKey( "PARTY_KEY");
            h0.defineData( "PARTY_KEY",
                           "HOUSEHOLD_KEY",
                           "CHANGE_BEGIN_DATE",
                           "SEGMENT_ID",
                           "CHANGE_CURRENT_IND",
                           "CHANGE_END_DATE");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: etls_temp_lookupview0";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " etls_temp_lookupview0";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: etls_temp_lookupview0";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " etls_temp_lookupview0";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " etls_temp_lookupview0";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " etls_temp_lookupview0";
         
         abort 3; 
      end; 
      
      call missing (PARTY_KEY, HOUSEHOLD_KEY, CHANGE_BEGIN_DATE, SEGMENT_ID, 
                    CHANGE_CURRENT_IND, CHANGE_END_DATE); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set iem.new_party_updates end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: PARTY_KEY);
   NEW_CHANGE_END_DATE = CHANGE_END_DATE;
   /* Examine success of lookups  */ 
   if ( rc0=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W8EZW87U; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Skip the record  */ 
         return; 
      end; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

data _null_;
  call symput('current_dt',put(datetime(),datetime22.));
run;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W88X4V5F;
quit;

proc sql;
   create table work.W88X4V5F as
      select
         PARTY_KEY,
         HOUSEHOLD_KEY,
         CHANGE_BEGIN_DATE,
         SEGMENT_ID,
         ("&current_dt"dt) as CHANGE_END_DATE length = 8
            format = DATETIME20.
            informat = DATETIME20.
            label = 'CHANGE_END_DATE',
         CHANGE_CURRENT_IND,
         NEW_PARTY_KEY,
         ("&current_dt"dt + 1) as NEW_CHANGE_BEGIN_DATE length = 8
            format = DATETIME20.
            informat = DATETIME20.,
         NEW_CHANGE_END_DATE
   from work.W8EZW87U
   ;
quit;

%let SOURCEDS = work.W88X4V5F;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8EZW87U;
quit;


/*==========================================================================* 
 * Step:            Update                                A5DG55RP.BV00034L * 
 * Transform:       Update                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W88X4V5F                A5DG55RP.BR000204 * 
 * Target Table:    FSC_HOUSEHOLD_PARTY_BRIDGE -          A5DG55RP.BH00019D * 
 *                   &db_core_libname..FSC_HOUSEHOLD_PARTY_BRIDGE           * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W88X4V5F); 

/*---- Update the target table  ----*/ 
proc sql;
   update &db_core_libname..FSC_HOUSEHOLD_PARTY_BRIDGE
      set 
         CHANGE_END_DATE= (
            select
               W88X4V5F.CHANGE_END_DATE length = 8   
                  format = DATETIME20.
                  informat = DATETIME20.
                  label = 'CHANGE_END_DATE'
            from
               work.W88X4V5F as W88X4V5F
            where
               FSC_HOUSEHOLD_PARTY_BRIDGE.PARTY_KEY = W88X4V5F.PARTY_KEY
               and FSC_HOUSEHOLD_PARTY_BRIDGE.HOUSEHOLD_KEY = W88X4V5F.HOUSEHOLD_KEY
         ),
         CHANGE_CURRENT_IND= 'N'
      where
         PARTY_KEY IN (
            select
               W88X4V5F.PARTY_KEY length = 8   
                  format = 13.
                  informat = 13.
                  label = 'PARTY_KEY'
            from
               work.W88X4V5F as W88X4V5F
         )
         and CHANGE_CURRENT_IND = 'Y'
   ;
quit;

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV00034N * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W88X4V5F                A5DG55RP.BR000204 * 
 * Target Table:    FSC_HOUSEHOLD_PARTY_BRIDGE -          A5DG55RP.BH00019D * 
 *                   &db_core_libname..FSC_HOUSEHOLD_PARTY_BRIDGE           * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W88X4V5F); 

proc datasets lib = work nolist nowarn memtype = (data view);
  delete W8AJ794Q;
quit;

proc sql;
  create view work.W8AJ794Q as
     select
        NEW_PARTY_KEY as PARTY_KEY,
        HOUSEHOLD_KEY,
        NEW_CHANGE_BEGIN_DATE as CHANGE_BEGIN_DATE,
        SEGMENT_ID,
        NEW_CHANGE_END_DATE as CHANGE_END_DATE,
        CHANGE_CURRENT_IND
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W8AJ794Q;

proc append base = &db_core_libname..FSC_HOUSEHOLD_PARTY_BRIDGE 
      data = &SOURCEDS force ; 
run; 
   
proc datasets lib = work nolist nowarn memtype = (data view);
  delete W8AJ794Q;
quit;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.$0001584 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Party Updates -                   A5DG55RP.BH0001BH * 
 *                   iem.new_party_updates                                  * 
 * Target Table:    PARTY_TYPE2NEW - iem.PARTY_TYPE2NEW   A5DG55RP.BH0001AL * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.new_party_updates); 

proc datasets lib = work nolist nowarn memtype = (data view);
  delete W9NHZNCL;
quit;

proc sql;
  create view work.W9NHZNCL as
     select
        PARTY_key   
           format = BEST32.,
        . as change_end_date length = 8
           format = DATETIME22.,
        . as change_begin_date length = 8
           format = DATETIME22.,
        "" as SEGMENT_ID length = 128
           format = $128.
           informat = $128.,
        PARTY_NUMBER,
        "" as PARTY_TYPE_DESC length = 20
           format = $20.
           informat = $20.,
        PARTY_TAX_ID,
        "" as PARTY_TAX_ID_TYPE_CODE length = 1
           format = $1.
           informat = $1.,
        "" as PARTY_IDENTIFICATION_ID length = 35
           format = $35.
           informat = $35.,
        "" as PARTY_IDENTIFICATION_TYPE_DESC length = 4
           format = $4.
           informat = $4.,
        "" as PARTY_ID_STATE_CODE length = 3
           format = $3.
           informat = $3.,
        . as PARTY_DATE_OF_BIRTH length = 8
           format = NLDATM.
           informat = NLDATM.,
        "" as PARTY_FIRST_NAME length = 35
           format = $35.
           informat = $35.,
        "" as PARTY_LAST_NAME length = 35
           format = $35.
           informat = $35.,
        "" as PARTY_MIDDLE_NAME length = 35
           format = $35.
           informat = $35.,
        PARTY_NAME length = 200   
           format = $200.
           informat = $200.,
        "" as DOING_BUSINESS_AS_NAME length = 35
           format = $35.
           informat = $35.,
        "" as PARTY_STATUS_DESC length = 20
           format = $20.
           informat = $20.,
        "" as ULTIMATE_PARENT_NAME length = 35
           format = $35.
           informat = $35.,
        "" as MATCH_CODE_ORGANIZATION length = 20
           format = $20.
           informat = $20.,
        "" as MATCH_CODE_INDIVIDUAL length = 20
           format = $20.
           informat = $20.,
        "" as MATCH_CODE_STREET_ADDRESS length = 40
           format = $40.
           informat = $40.,
        "" as MATCH_CODE_MAILING_ADDRESS length = 40
           format = $40.
           informat = $40.,
        "" as STREET_ADDRESS_1 length = 35
           format = $35.
           informat = $35.,
        "" as STREET_ADDRESS_2 length = 35
           format = $35.
           informat = $35.,
        "" as STREET_CITY_NAME length = 35
           format = $35.
           informat = $35.,
        "" as STREET_STATE_CODE length = 3
           format = $3.
           informat = $3.,
        "" as STREET_STATE_NAME length = 35
           format = $35.
           informat = $35.,
        "" as STREET_POSTAL_CODE length = 10
           format = $10.
           informat = $10.,
        "" as STREET_COUNTRY_CODE length = 3
           format = $3.
           informat = $3.,
        "" as STREET_COUNTRY_NAME length = 100
           format = $100.
           informat = $100.,
        "" as MAILING_ADDRESS_1 length = 35
           format = $35.
           informat = $35.,
        "" as MAILING_ADDRESS_2 length = 35
           format = $35.
           informat = $35.,
        "" as MAILING_CITY_NAME length = 35
           format = $35.
           informat = $35.,
        "" as MAILING_STATE_CODE length = 3
           format = $3.
           informat = $3.,
        "" as MAILING_STATE_NAME length = 35
           format = $35.
           informat = $35.,
        "" as MAILING_POSTAL_CODE length = 10
           format = $10.
           informat = $10.,
        "" as MAILING_COUNTRY_CODE length = 3
           format = $3.
           informat = $3.,
        "" as MAILING_COUNTRY_NAME length = 100
           format = $100.
           informat = $100.,
        "" as RESIDENCE_COUNTRY_CODE length = 3
           format = $3.
           informat = $3.,
        "" as RESIDENCE_COUNTRY_NAME length = 100
           format = $100.
           informat = $100.,
        "" as CITIZENSHIP_COUNTRY_CODE length = 3
           format = $3.
           informat = $3.,
        "" as CITIZENSHIP_COUNTRY_NAME length = 100
           format = $100.
           informat = $100.,
        "" as ORG_COUNTRY_OF_BUSINESS_CODE length = 3
           format = $3.
           informat = $3.,
        "" as ORG_COUNTRY_OF_BUSINESS_NAME length = 100
           format = $100.
           informat = $100.,
        "" as EMPLOYEE_IND length = 1
           format = $1.
           informat = $1.,
        "" as EMPLOYEE_NUMBER length = 20
           format = $20.
           informat = $20.,
        "" as EMPLOYER_NAME length = 35
           format = $35.
           informat = $35.,
        "" as EMPLOYER_PHONE_NUMBER length = 25
           format = $25.
           informat = $25.,
        "" as EMAIL_ADDRESS length = 35
           format = $35.
           informat = $35.,
        "" as OCCUPATION_DESC length = 35
           format = $35.
           informat = $35.,
        "" as INDUSTRY_CODE length = 10
           format = $10.
           informat = $10.,
        "" as INDUSTRY_DESC length = 255
           format = $255.
           informat = $255.,
        "" as PHONE_NUMBER_1 length = 25
           format = $25.
           informat = $25.,
        "" as PHONE_NUMBER_2 length = 25
           format = $25.
           informat = $25.,
        "" as PHONE_NUMBER_3 length = 25
           format = $25.
           informat = $25.,
        . as ANNUAL_INCOME_AMOUNT length = 8
           format = 11.
           informat = 11.,
        . as NET_WORTH_AMOUNT length = 8
           format = 11.
           informat = 11.,
        "" as MARITAL_STATUS_DESC length = 20
           format = $20.
           informat = $20.,
        . as LAST_CONTACT_DATE length = 8
           format = NLDATM.
           informat = NLDATM.,
        "" as POLITICALLY_EXPOSED_PERSON_IND length = 1
           format = $1.
           informat = $1.,
        "" as NON_PROFIT_ORG_IND length = 1
           format = $1.
           informat = $1.,
        . as CUSTOMER_SINCE_DATE length = 8
           format = NLDATM.
           informat = NLDATM.,
        . as LAST_CASH_TRANS_RPT_DATE length = 8
           format = NLDATM.
           informat = NLDATM.,
        . as LAST_SUSP_ACTV_RPT_DATE length = 8
           format = DATETIME25.6
           informat = DATETIME25.6,
        LAST_RISK_ASSESSMENT_DATE   
           format = DATETIME25.6
           informat = DATETIME25.6,
        RISK_CLASSIFICATION,
        "" as change_digest_1 length = 32,
        "" as change_digest_2 length = 32,
        "" as change_current_ind length = 1
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W9NHZNCL;

proc datasets lib = iem nolist nowarn memtype = (data view);
  delete PARTY_TYPE2NEW;
quit;

data iem.PARTY_TYPE2NEW;
  attrib PARTY_key length = 8
     format = BEST32.
     informat = 13.
     label = 'PARTY_KEY'; 
  attrib change_end_date length = 8
     format = DATETIME22.; 
  attrib change_begin_date length = 8
     format = DATETIME22.; 
  attrib SEGMENT_ID length = $128
     format = $128.
     informat = $128.
     label = 'SEGMENT_ID'; 
  attrib PARTY_NUMBER length = $50
     format = $50.
     informat = $50.
     label = 'PARTY_NUMBER'; 
  attrib PARTY_TYPE_DESC length = $20
     format = $20.
     informat = $20.
     label = 'PARTY_TYPE_DESC'; 
  attrib PARTY_TAX_ID length = $35
     format = $35.
     informat = $35.
     label = 'PARTY_TAX_ID'; 
  attrib PARTY_TAX_ID_TYPE_CODE length = $1
     format = $1.
     informat = $1.
     label = 'PARTY_TAX_ID_TYPE_CODE'; 
  attrib PARTY_IDENTIFICATION_ID length = $35
     format = $35.
     informat = $35.
     label = 'PARTY_IDENTIFICATION_ID'; 
  attrib PARTY_IDENTIFICATION_TYPE_DESC length = $4
     format = $4.
     informat = $4.
     label = 'PARTY_IDENTIFICATION_TYPE_DESC'; 
  attrib PARTY_ID_STATE_CODE length = $3
     format = $3.
     informat = $3.
     label = 'PARTY_ID_STATE_CODE'; 
  attrib PARTY_DATE_OF_BIRTH length = 8
     format = NLDATM.
     informat = NLDATM.
     label = 'PARTY_DATE_OF_BIRTH'; 
  attrib PARTY_FIRST_NAME length = $35
     format = $35.
     informat = $35.
     label = 'PARTY_FIRST_NAME'; 
  attrib PARTY_LAST_NAME length = $35
     format = $35.
     informat = $35.
     label = 'PARTY_LAST_NAME'; 
  attrib PARTY_MIDDLE_NAME length = $35
     format = $35.
     informat = $35.
     label = 'PARTY_MIDDLE_NAME'; 
  attrib PARTY_NAME length = $200
     format = $200.
     informat = $200.
     label = 'PARTY_NAME'; 
  attrib DOING_BUSINESS_AS_NAME length = $35
     format = $35.
     informat = $35.
     label = 'DOING_BUSINESS_AS_NAME'; 
  attrib PARTY_STATUS_DESC length = $20
     format = $20.
     informat = $20.
     label = 'PARTY_STATUS_DESC'; 
  attrib ULTIMATE_PARENT_NAME length = $35
     format = $35.
     informat = $35.
     label = 'ULTIMATE_PARENT_NAME'; 
  attrib MATCH_CODE_ORGANIZATION length = $20
     format = $20.
     informat = $20.
     label = 'MATCH_CODE_ORGANIZATION'; 
  attrib MATCH_CODE_INDIVIDUAL length = $20
     format = $20.
     informat = $20.
     label = 'MATCH_CODE_INDIVIDUAL'; 
  attrib MATCH_CODE_STREET_ADDRESS length = $40
     format = $40.
     informat = $40.
     label = 'MATCH_CODE_STREET_ADDRESS'; 
  attrib MATCH_CODE_MAILING_ADDRESS length = $40
     format = $40.
     informat = $40.
     label = 'MATCH_CODE_MAILING_ADDRESS'; 
  attrib STREET_ADDRESS_1 length = $35
     format = $35.
     informat = $35.
     label = 'STREET_ADDRESS_1'; 
  attrib STREET_ADDRESS_2 length = $35
     format = $35.
     informat = $35.
     label = 'STREET_ADDRESS_2'; 
  attrib STREET_CITY_NAME length = $35
     format = $35.
     informat = $35.
     label = 'STREET_CITY_NAME'; 
  attrib STREET_STATE_CODE length = $3
     format = $3.
     informat = $3.
     label = 'STREET_STATE_CODE'; 
  attrib STREET_STATE_NAME length = $35
     format = $35.
     informat = $35.
     label = 'STREET_STATE_NAME'; 
  attrib STREET_POSTAL_CODE length = $10
     format = $10.
     informat = $10.
     label = 'STREET_POSTAL_CODE'; 
  attrib STREET_COUNTRY_CODE length = $3
     format = $3.
     informat = $3.
     label = 'STREET_COUNTRY_CODE'; 
  attrib STREET_COUNTRY_NAME length = $100
     format = $100.
     informat = $100.
     label = 'STREET_COUNTRY_NAME'; 
  attrib MAILING_ADDRESS_1 length = $35
     format = $35.
     informat = $35.
     label = 'MAILING_ADDRESS_1'; 
  attrib MAILING_ADDRESS_2 length = $35
     format = $35.
     informat = $35.
     label = 'MAILING_ADDRESS_2'; 
  attrib MAILING_CITY_NAME length = $35
     format = $35.
     informat = $35.
     label = 'MAILING_CITY_NAME'; 
  attrib MAILING_STATE_CODE length = $3
     format = $3.
     informat = $3.
     label = 'MAILING_STATE_CODE'; 
  attrib MAILING_STATE_NAME length = $35
     format = $35.
     informat = $35.
     label = 'MAILING_STATE_NAME'; 
  attrib MAILING_POSTAL_CODE length = $10
     format = $10.
     informat = $10.
     label = 'MAILING_POSTAL_CODE'; 
  attrib MAILING_COUNTRY_CODE length = $3
     format = $3.
     informat = $3.
     label = 'MAILING_COUNTRY_CODE'; 
  attrib MAILING_COUNTRY_NAME length = $100
     format = $100.
     informat = $100.
     label = 'MAILING_COUNTRY_NAME'; 
  attrib RESIDENCE_COUNTRY_CODE length = $3
     format = $3.
     informat = $3.
     label = 'RESIDENCE_COUNTRY_CODE'; 
  attrib RESIDENCE_COUNTRY_NAME length = $100
     format = $100.
     informat = $100.
     label = 'RESIDENCE_COUNTRY_NAME'; 
  attrib CITIZENSHIP_COUNTRY_CODE length = $3
     format = $3.
     informat = $3.
     label = 'CITIZENSHIP_COUNTRY_CODE'; 
  attrib CITIZENSHIP_COUNTRY_NAME length = $100
     format = $100.
     informat = $100.
     label = 'CITIZENSHIP_COUNTRY_NAME'; 
  attrib ORG_COUNTRY_OF_BUSINESS_CODE length = $3
     format = $3.
     informat = $3.
     label = 'ORG_COUNTRY_OF_BUSINESS_CODE'; 
  attrib ORG_COUNTRY_OF_BUSINESS_NAME length = $100
     format = $100.
     informat = $100.
     label = 'ORG_COUNTRY_OF_BUSINESS_NAME'; 
  attrib EMPLOYEE_IND length = $1
     format = $1.
     informat = $1.
     label = 'EMPLOYEE_IND'; 
  attrib EMPLOYEE_NUMBER length = $20
     format = $20.
     informat = $20.
     label = 'EMPLOYEE_NUMBER'; 
  attrib EMPLOYER_NAME length = $35
     format = $35.
     informat = $35.
     label = 'EMPLOYER_NAME'; 
  attrib EMPLOYER_PHONE_NUMBER length = $25
     format = $25.
     informat = $25.
     label = 'EMPLOYER_PHONE_NUMBER'; 
  attrib EMAIL_ADDRESS length = $35
     format = $35.
     informat = $35.
     label = 'EMAIL_ADDRESS'; 
  attrib OCCUPATION_DESC length = $35
     format = $35.
     informat = $35.
     label = 'OCCUPATION_DESC'; 
  attrib INDUSTRY_CODE length = $10
     format = $10.
     informat = $10.
     label = 'INDUSTRY_CODE'; 
  attrib INDUSTRY_DESC length = $255
     format = $255.
     informat = $255.
     label = 'INDUSTRY_DESC'; 
  attrib PHONE_NUMBER_1 length = $25
     format = $25.
     informat = $25.
     label = 'PHONE_NUMBER_1'; 
  attrib PHONE_NUMBER_2 length = $25
     format = $25.
     informat = $25.
     label = 'PHONE_NUMBER_2'; 
  attrib PHONE_NUMBER_3 length = $25
     format = $25.
     informat = $25.
     label = 'PHONE_NUMBER_3'; 
  attrib ANNUAL_INCOME_AMOUNT length = 8
     format = 11.
     informat = 11.
     label = 'ANNUAL_INCOME_AMOUNT'; 
  attrib NET_WORTH_AMOUNT length = 8
     format = 11.
     informat = 11.
     label = 'NET_WORTH_AMOUNT'; 
  attrib MARITAL_STATUS_DESC length = $20
     format = $20.
     informat = $20.
     label = 'MARITAL_STATUS_DESC'; 
  attrib LAST_CONTACT_DATE length = 8
     format = NLDATM.
     informat = NLDATM.
     label = 'LAST_CONTACT_DATE'; 
  attrib POLITICALLY_EXPOSED_PERSON_IND length = $1
     format = $1.
     informat = $1.
     label = 'POLITICALLY_EXPOSED_PERSON_IND'; 
  attrib NON_PROFIT_ORG_IND length = $1
     format = $1.
     informat = $1.
     label = 'NON_PROFIT_ORG_IND'; 
  attrib CUSTOMER_SINCE_DATE length = 8
     format = NLDATM.
     informat = NLDATM.
     label = 'CUSTOMER_SINCE_DATE'; 
  attrib LAST_CASH_TRANS_RPT_DATE length = 8
     format = NLDATM.
     informat = NLDATM.
     label = 'LAST_CASH_TRANS_RPT_DATE'; 
  attrib LAST_SUSP_ACTV_RPT_DATE length = 8
     format = DATETIME25.6
     informat = DATETIME25.6
     label = 'LAST_SUSP_ACTV_RPT_DATE'; 
  attrib LAST_RISK_ASSESSMENT_DATE length = 8
     format = DATETIME25.6
     informat = DATETIME25.6
     label = 'LAST_RISK_ASSESSMENT_DATE'; 
  attrib RISK_CLASSIFICATION length = 8
     format = 2.
     informat = 2.
     label = 'RISK_CLASSIFICATION'; 
  attrib change_digest_1 length = $32; 
  attrib change_digest_2 length = $32; 
  attrib change_current_ind length = $1; 
  call missing(of _all_);
  stop;
run;
   
proc append base = iem.PARTY_TYPE2NEW 
   data = &SOURCEDS force ; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W9NHZNCL;
quit;

/* Call Party Update to return new AML key to ECM */
%fcf_iem_update_party


%mend;
