%macro fcf_iem_load_associate(ds=);

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002QS * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    ASSOCIATE_NEW - iem.ASSOCIATE_NEW     A5DG55RP.BH0001A6 * 
 * Target Table:    Extract - work.W1CP7SQ0               A5DG55RP.BR0001T2 * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(&ds); 

/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1CP7SQ0;
quit;

proc sql;
   create view work.W1CP7SQ0 as
      select
         ASSOCIATE_KEY,
         ASSOCIATE_NUMBER,
         (CATX(' ',ASSOCIATE_FIRST_NAME,ASSOCIATE_MIDDLE_NAME,ASSOCIATE_LAST_NAME)) as ASSOCIATE_FULL_NAME length = 200
            format = $200.
            informat = $200.
            label = 'ASSOCIATE_FULL_NAME'
   from &SOURCEDS
      where CHANGE_CURRENT_IND = "Y" & SEGMENT_ID = "&segKCSchema"
   ;
quit;

%let SOURCEDS = work.W1CP7SQ0;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002QT * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Extract - work.W1CP7SQ0               A5DG55RP.BR0001T2 * 
 * Target Table:    New Parties - iem.new_parties         A5DG55RP.BH0001AU * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W1CP7SQ0); 
   
   data _null_;
      call symput('current_dt',put(datetime(),datetime22.));
   run;

   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5Y977TX;
   quit;
   
   proc sql;
      create view work.W5Y977TX as
         select
            . as PARTY_RK length = 8
               format = 11.
               informat = 11.,
            ("&current_dt"dt) as VALID_FROM_DTTM length = 8
               format = DATETIME27.6
               informat = DATETIME27.6,
            . as VALID_TO_DTTM length = 8
               format = DATETIME27.6
               informat = DATETIME27.6,
            (CATX('-','ASC',ASSOCIATE_NUMBER)) as PARTY_ID length = 50
               format = $50.
               informat = $50.,
            ("&segKCschema") as SOURCE_SYSTEM_CD length = 10
               format = $10.
               informat = $10.,
            ("FCFSUB") as PARTY_TYPE_CD length = 32
               format = $32.
               informat = $32.,
            ("ASC") as PARTY_CATEGORY_CD length = 32
               format = $32.
               informat = $32.,
            "" as PARTY_SUBCATEGORY_CD length = 32
               format = $32.
               informat = $32.,
            . as IDENTICAL_PARTY_LINK_SK length = 8
               format = 11.
               informat = 11.,
            ("0") as INDIVIDUAL_FLG length = 1
               format = $1.
               informat = $1.,
            ASSOCIATE_FULL_NAME as PARTY_FULL_NM,
            "" as NATIONAL_ID length = 32
               format = $32.
               informat = $32.,
            "" as NATIONAL_ID_TYPE_CD length = 10
               format = $10.
               informat = $10.,
            "" as UI_DEF_FILE_NM length = 100
               format = $100.
               informat = $100.,
            ("&ecm_user") as CREATE_USER_ID length = 60
               format = $60.
               informat = $60.,
            ("&current_dt"dt) as CREATE_DTTM length = 8
               format = DATETIME27.6
               informat = DATETIME27.6,
            ("&ecm_user") as UPDATE_USER_ID length = 60
               format = $60.
               informat = $60.,
            (1) as VERSION_NO length = 8
               format = 11.
               informat = 11.,
            ("0") as DELETE_FLG length = 1
               format = $1.
               informat = $1.,
            ASSOCIATE_KEY
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W5Y977TX;
    
   proc datasets lib = iem nolist nowarn memtype = (data view);
      delete new_parties;
   quit;
   
   data iem.new_parties;
      attrib PARTY_RK length = 8
         format = 11.
         informat = 11.
         label = 'PARTY_RK'; 
      attrib VALID_FROM_DTTM length = 8
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_FROM_DTTM'; 
      attrib VALID_TO_DTTM length = 8
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_TO_DTTM'; 
      attrib PARTY_ID length = $50
         format = $50.
         informat = $50.
         label = 'PARTY_ID'; 
      attrib SOURCE_SYSTEM_CD length = $10
         format = $10.
         informat = $10.
         label = 'SOURCE_SYSTEM_CD'; 
      attrib PARTY_TYPE_CD length = $32
         format = $32.
         informat = $32.
         label = 'PARTY_TYPE_CD'; 
      attrib PARTY_CATEGORY_CD length = $32
         format = $32.
         informat = $32.
         label = 'PARTY_CATEGORY_CD'; 
      attrib PARTY_SUBCATEGORY_CD length = $32
         format = $32.
         informat = $32.
         label = 'PARTY_SUBCATEGORY_CD'; 
      attrib IDENTICAL_PARTY_LINK_SK length = 8
         format = 11.
         informat = 11.
         label = 'IDENTICAL_PARTY_LINK_SK'; 
      attrib INDIVIDUAL_FLG length = $1
         format = $1.
         informat = $1.
         label = 'INDIVIDUAL_FLG'; 
      attrib PARTY_FULL_NM length = $200
         format = $200.
         informat = $200.
         label = 'PARTY_FULL_NM'; 
      attrib NATIONAL_ID length = $32
         format = $32.
         informat = $32.
         label = 'NATIONAL_ID'; 
      attrib NATIONAL_ID_TYPE_CD length = $10
         format = $10.
         informat = $10.
         label = 'NATIONAL_ID_TYPE_CD'; 
      attrib UI_DEF_FILE_NM length = $100
         format = $100.
         informat = $100.
         label = 'UI_DEF_FILE_NM'; 
      attrib CREATE_USER_ID length = $60
         format = $60.
         informat = $60.
         label = 'CREATE_USER_ID'; 
      attrib CREATE_DTTM length = 8
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'CREATE_DTTM'; 
      attrib UPDATE_USER_ID length = $60
         format = $60.
         informat = $60.
         label = 'UPDATE_USER_ID'; 
      attrib VERSION_NO length = 8
         format = 11.
         informat = 11.
         label = 'VERSION_NO'; 
      attrib DELETE_FLG length = $1
         format = $1.
         informat = $1.
         label = 'DELETE_FLG'; 
      attrib ASSOCIATE_KEY length = 8
         format = 13.
         informat = 13.
         label = 'ASSOCIATE_KEY'; 
      call missing(of _all_);
      stop;
   run;
   
proc append base = iem.new_parties 
   data = &SOURCEDS force; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5Y977TX;
quit;

/*---- Start of Post-Process Code  ----*/ 

%let obs_count = %fcf_get_observation_count(table=iem.new_parties, SASDATASET=Y);
%let numevents = &obs_count;

%fcf_get_ecm_sequence_ids(numIDs=&numevents, ecmSeq=party);

data iem.new_parties;
	set iem.new_parties;
	party_rk = symgetn('seqId'||(kstrip(put(_n_,best32.))));
run;
/*---- End of Post-Process Code  ----*/ 

/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002QU * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   New Parties - iem.new_parties         A5DG55RP.BH0001AU * 
 *                  PARTY_CONFIG - ecm_db.PARTY_CONFIG    A5DG55RP.BH00019U * 
 * Target Table:    Lookup - work.W1DEZWMG                A5DG55RP.BR0001T3 * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1DEZWMG;
quit;

DATA  work.W1DEZWMG
         (keep = PARTY_RK VALID_FROM_DTTM VALID_TO_DTTM PARTY_ID SOURCE_SYSTEM_CD 
                 PARTY_TYPE_CD PARTY_CATEGORY_CD PARTY_SUBCATEGORY_CD 
                 IDENTICAL_PARTY_LINK_SK INDIVIDUAL_FLG PARTY_FULL_NM NATIONAL_ID 
                 NATIONAL_ID_TYPE_CD UI_DEF_FILE_NM CREATE_USER_ID CREATE_DTTM 
                 UPDATE_USER_ID VERSION_NO DELETE_FLG ASSOCIATE_KEY)
      ; 
   
   attrib PARTY_RK length=8 format=11. label="PARTY_RK"
          VALID_FROM_DTTM length=8 format=DATETIME27.6 label="VALID_FROM_DTTM"
          VALID_TO_DTTM length=8 format=DATETIME27.6 label="VALID_TO_DTTM"
          PARTY_ID length=$50 format=$50. label="PARTY_ID"
          SOURCE_SYSTEM_CD length=$10 format=$10. label="SOURCE_SYSTEM_CD"
          PARTY_TYPE_CD length=$32 format=$32. label="PARTY_TYPE_CD"
          PARTY_CATEGORY_CD length=$32 format=$32. label="PARTY_CATEGORY_CD"
          PARTY_SUBCATEGORY_CD length=$32 format=$32. label="PARTY_SUBCATEGORY_CD"
          IDENTICAL_PARTY_LINK_SK length=8 format=11. label="IDENTICAL_PARTY_LINK_SK"
          INDIVIDUAL_FLG length=$1 format=$1. label="INDIVIDUAL_FLG"
          PARTY_FULL_NM length=$200 format=$200. label="PARTY_FULL_NM"
          NATIONAL_ID length=$32 format=$32. label="NATIONAL_ID"
          NATIONAL_ID_TYPE_CD length=$10 format=$10. label="NATIONAL_ID_TYPE_CD"
          UI_DEF_FILE_NM length=$100 format=$100. label="UI_DEF_FILE_NM"
          CREATE_USER_ID length=$60 format=$60. label="CREATE_USER_ID"
          CREATE_DTTM length=8 format=DATETIME27.6 label="CREATE_DTTM"
          UPDATE_USER_ID length=$60 format=$60. label="UPDATE_USER_ID"
          VERSION_NO length=8 format=11. label="VERSION_NO"
          DELETE_FLG length=$1 format=$1. label="DELETE_FLG"
		  ASSOCIATE_KEY length=8 format=13. label="ASSOCIATE_KEY"
          ; 
   
   retain missing0-missing0 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table ecm_db.PARTY_CONFIG */ 
      nlobs = .; 
      dsid = open("ecm_db.PARTY_CONFIG"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "ecm_db.PARTY_CONFIG", hashexp: exponent);
            h0.defineKey( "PARTY_TYPE_CD",
                           "PARTY_CATEGORY_CD",
                           "PARTY_SUBCATEGORY_CD");
            h0.defineData( "UI_DEF_FILE_NM");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: ecm_db.PARTY_CONFIG";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " ecm_db.PARTY_CONFIG";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: ecm_db.PARTY_CONFIG";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " ecm_db.PARTY_CONFIG";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " ecm_db.PARTY_CONFIG";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " ecm_db.PARTY_CONFIG";
         
         abort 3; 
      end; 
      
      call missing (PARTY_TYPE_CD, PARTY_CATEGORY_CD, PARTY_SUBCATEGORY_CD, 
                    UI_DEF_FILE_NM); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set iem.new_parties end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: PARTY_TYPE_CD, key: PARTY_CATEGORY_CD, key: PARTY_SUBCATEGORY_CD);
   /* Examine success of lookups  */ 
   if ( rc0=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W1DEZWMG; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to value  */ 
         UI_DEF_FILE_NM = "fcf-associate-details-01.xml";
         etls_assign_target_value = 1; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.W1DEZWMG; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002QV * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W1DEZWMG                A5DG55RP.BR0001T3 * 
 * Target Table:    PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W1DEZWMG); 

proc datasets lib = work nolist nowarn memtype = (data view);
  delete W5Y9780J;
quit;

proc append base = ecm_db.PARTY_LIVE 
  data = &SOURCEDS force; 
run; 

proc datasets lib = work nolist nowarn memtype = (data view);
  delete W5Y9780J;
quit;

/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002QW * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W1DEZWMG                A5DG55RP.BR0001T3 * 
 * Target Table:    PARTY_VERSION - ecm_db.PARTY_VERSION  A5DG55RP.BH00019Z * 
 *                                                                          * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W1DEZWMG); 
   
   proc append base = ecm_db.PARTY_VERSION 
      data = &SOURCEDS force; 
    run; 
   
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5Y9788C;
   quit;
 
/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002QX * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W1DEZWMG                A5DG55RP.BR0001T3 * 
 * Target Table:    PARTY_X_USER_GROUP -                  A5DG55RP.BH0001A1 * 
 *                   ecm_db.PARTY_X_USER_GROUP                              * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W1DEZWMG); 

proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5Y978CD;
   quit;
   
   proc sql;
      create view work.W5Y978CD as
         select
            PARTY_RK,
            ("&ecm_user_group") as USER_GROUP_NM length = 60
               format = $60.
               informat = $60.
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W5Y978CD;
   
   proc append base = ecm_db.PARTY_X_USER_GROUP 
      data = &SOURCEDS force; 
    run; 
   
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5Y978CD;
   quit;

/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002QY * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W1DEZWMG                A5DG55RP.BR0001T3 * 
 * Target Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W1DEZWMG); 

proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5Y978JP;
   quit;
   
   proc sql;
      create view work.W5Y978JP as
         select
            . as EVENT_RK length = 8
               format = 11.
               informat = 11.,
			("PARTY") as BUSINESS_OBJECT_NM length = 100
               format = $100.
               informat = $100.,
            PARTY_RK as BUSINESS_OBJECT_RK,
            ("LOADEN") as EVENT_TYPE_CD length = 10
               format = $10.
               informat = $10.,
            ("event.etl.load.txt") as EVENT_DESC length = 256
               format = $256.
               informat = $256.,
            CREATE_USER_ID,
            CREATE_DTTM,
            "" as LINKED_OBJECT_NM length = 100
               format = $100.
               informat = $100.,
            . as LINKED_OBJECT_RK length = 8
               format = 11.
               informat = 11.
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W5Y978JP;
   
   proc datasets lib = iem nolist nowarn memtype = (data view);
      delete new_events;
   quit;
   
   data iem.new_events;
      attrib EVENT_RK length = 8
         format = 11.
         informat = 11.
         label = 'EVENT_RK'; 
	  attrib BUSINESS_OBJECT_NM length = $100
         format = $100.
         informat = $100.
         label = 'BUSINESS_OBJECT_NM';
      attrib BUSINESS_OBJECT_RK length = 8
         format = 11.
         informat = 11.
         label = 'BUSINESS_OBJECT_RK'; 
      attrib EVENT_TYPE_CD length = $10
         format = $10.
         informat = $10.
         label = 'EVENT_TYPE_CD'; 
      attrib EVENT_DESC length = $256
         format = $256.
         informat = $256.
         label = 'EVENT_DESC'; 
      attrib CREATE_USER_ID length = $60
         format = $60.
         informat = $60.
         label = 'CREATE_USER_ID'; 
      attrib CREATE_DTTM length = 8
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'CREATE_DTTM'; 
      attrib LINKED_OBJECT_NM length = $100
         format = $100.
         informat = $100.
         label = 'LINKED_OBJECT_NM'; 
      attrib LINKED_OBJECT_RK length = 8
         format = 11.
         informat = 11.
         label = 'LINKED_OBJECT_RK'; 
      call missing(of _all_);
      stop;
   run;

proc append base = iem.new_events 
   data = &SOURCEDS force; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5Y978JP;
quit;

/*---- Start of Post-Process Code  ----*/ 

%let obs_count = %fcf_get_observation_count(table=iem.new_events, SASDATASET=Y);
%let numevents = &obs_count;

%fcf_get_ecm_sequence_ids(numIDs=&numevents, ecmSeq=event);

data iem.new_events;
	set iem.new_events;
	event_rk = symgetn('seqId'||(kstrip(put(_n_,best32.))));
run;
/*---- End of Post-Process Code  ----*/ 

/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002QZ * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 * Target Table:    ECM_EVENT - ecm_db.ECM_EVENT          A5DG55RP.BH00019J * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.new_events); 

proc append base = ecm_db.ECM_EVENT 
  data = &SOURCEDS force; 
run; 
   




/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV000316 * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W1DEZWMG                A5DG55RP.BR0001T3 * 
 * Target Table:    Extract - work.W5B08DB0               A5DG55RP.BR0001XV * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W1DEZWMG); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5B08DB0;
quit;

proc sql;
   create view work.W5B08DB0 as
      select
         PARTY_RK,
         VALID_FROM_DTTM,
         ASSOCIATE_KEY as X_SASFCS_PTY_KEY
   from &SOURCEDS
   ;
quit;

%let SOURCEDS = work.W5B08DB0;


/*==========================================================================* 
 * Step:            Transpose                             A5DG55RP.BV000317 * 
 * Transform:       Transpose                                               * 
 * Description:     Creates an output table by restructuring the values in  * 
 *                  the source table, transposing selected columns into     * 
 *                   rows.                                                  * 
 *                                                                          * 
 * Source Table:    Extract - work.W5B08DB0               A5DG55RP.BR0001XV * 
 * Target Table:    Subject Numeric UDF Fields -          A5DG55RP.BH0001B0 * 
 *                   iem.Subject_Numeric_Udf_Fields                         * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W5B08DB0); 

%let _INPUT = work.W5B08DB0;
%let _INPUT_options = %nrquote();
%let _OUTPUT = iem.Subject_Numeric_Udf_Fields;
%let _OUTPUT_options = %nrquote();

proc datasets lib=iem nolist nowarn memtype = (data view);
   delete Subject_Numeric_Udf_Fields;
quit;

%let varColumns = X_SASFCS_PTY_KEY;
%let byColumns = PARTY_RK VALID_FROM_DTTM;

proc transpose data = &_INPUT (&_INPUT_options) out = &_OUTPUT (&_OUTPUT_options);
  	by &byColumns;
  	var &varColumns;
run;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV000318 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Subject Numeric UDF Fields -          A5DG55RP.BH0001B0 * 
 *                   iem.Subject_Numeric_Udf_Fields                         * 
 * Target Table:    PARTY_UDF_NUM_VALUE -                 A5DG55RP.BH00019Y * 
 *                   ecm_db.PARTY_UDF_NUM_VALUE                             * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.Subject_Numeric_Udf_Fields); 
   
proc datasets lib = work nolist nowarn memtype = (data view);
  delete W5B2YWCW;
quit;

proc sql;
  create view work.W5B2YWCW as
     select
        PARTY_RK,
        VALID_FROM_DTTM,
        ('PARTY') as UDF_TABLE_NM length = 30
           format = $30.
           informat = $30.,
        _NAME_ as UDF_NM length = 30   
           format = $30.
           informat = $30.,
        (1) as ROW_NO length = 8
           format = 11.
           informat = 11.,
        COL1 as UDF_VALUE
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W5B2YWCW;

proc append base = ecm_db.PARTY_UDF_NUM_VALUE 
  data = &SOURCEDS force ; 
run; 

proc datasets lib = work nolist nowarn memtype = (data view);
  delete W5B2YWCW;
quit;
   

%mend;
