%macro fcf_iem_update_party;

/*==========================================================================* 
 * Step:            Append                                A5DG55RP.BV0002XM * 
 * Transform:       Append                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   PARTY_TYPE1UPDATE -                   A5DG55RP.BH0001AK * 
 *                   iem.PARTY_TYPE1UPDATE                                  * 
 *                  PARTY_TYPE2NEW - iem.PARTY_TYPE2NEW   A5DG55RP.BH0001AL * 
 * Target Table:    Append - work.W3IYGTXH                A5DG55RP.BR0001VU * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8PULUOC;
quit;

proc sql;
   create view work.W8PULUOC as
      select
         PARTY_key,
         PARTY_NUMBER,
         PARTY_TAX_ID,
         PARTY_NAME,
         RISK_CLASSIFICATION
   from iem.PARTY_TYPE1UPDATE
   ;
quit;

%let SOURCEDS = work.W8PULUOC;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8PULUOG;
quit;

proc sql;
   create view work.W8PULUOG as
      select
         PARTY_key,
         PARTY_NUMBER,
         PARTY_TAX_ID,
         PARTY_NAME,
         RISK_CLASSIFICATION
   from iem.PARTY_TYPE2NEW
   ;
quit;

%let SOURCEDS = work.W8PULUOG;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W3IYGTXH;
quit;

data work.W3IYGTXH / view=work.W3IYGTXH;
   set work.W8PULUOC
       work.W8PULUOG;
   keep PARTY_key PARTY_NUMBER PARTY_TAX_ID PARTY_NAME RISK_CLASSIFICATION; 
run;


/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002XN * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Append - work.W3IYGTXH                A5DG55RP.BR0001VU * 
 * Target Table:    Extract - work.W227S7ML               A5DG55RP.BR0001VV * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W3IYGTXH); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W227S7ML;
quit;

proc sql;
   create view work.W227S7ML as
      select
         PARTY_key,
         (CATX('-','PTY',PARTY_NUMBER)) as PARTY_ID length = 50
            format = $50.
            informat = $50.
            label = 'PARTY_ID',
         PARTY_TAX_ID,
         PARTY_NAME as PARTY_FULL_NM   
            label = 'PARTY_FULL_NM',
         RISK_CLASSIFICATION
   from &SOURCEDS
   ;
quit;

%let SOURCEDS = work.W227S7ML;

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002XO * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Extract - work.W227S7ML               A5DG55RP.BR0001VV * 
 *                  PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 * Target Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VW * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8PULUU3;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.W8PULUU3
         (keep = PARTY_RK VALID_FROM_DTTM VALID_TO_DTTM PARTY_ID SOURCE_SYSTEM_CD 
                 PARTY_TYPE_CD PARTY_CATEGORY_CD PARTY_SUBCATEGORY_CD 
                 IDENTICAL_PARTY_LINK_SK INDIVIDUAL_FLG PARTY_FULL_NM NATIONAL_ID 
                 NATIONAL_ID_TYPE_CD UI_DEF_FILE_NM CREATE_USER_ID CREATE_DTTM 
                 UPDATE_USER_ID VERSION_NO DELETE_FLG PARTY_TAX_ID RISK_CLASSIFICATION 
                 PARTY_key OLD_VALID_FROM_DTTM )
      ; 
   
   attrib PARTY_RK length=8 format=11. label="PARTY_RK"
          VALID_FROM_DTTM length=8 format=DATETIME27.6 label="VALID_FROM_DTTM"
          VALID_TO_DTTM length=8 format=DATETIME27.6 label="VALID_TO_DTTM"
          PARTY_ID length=$50 format=$50. label="PARTY_ID"
          SOURCE_SYSTEM_CD length=$10 format=$10. label="SOURCE_SYSTEM_CD"
          PARTY_TYPE_CD length=$32 format=$32. label="PARTY_TYPE_CD"
          PARTY_CATEGORY_CD length=$32 format=$32. label="PARTY_CATEGORY_CD"
          PARTY_SUBCATEGORY_CD length=$32 format=$32. label="PARTY_SUBCATEGORY_CD"
          IDENTICAL_PARTY_LINK_SK length=8 format=11. label="IDENTICAL_PARTY_LINK_SK"
          INDIVIDUAL_FLG length=$1 format=$1. label="INDIVIDUAL_FLG"
          PARTY_FULL_NM length=$35 format=$35. label="PARTY_FULL_NM"
          NATIONAL_ID length=$32 format=$32. label="NATIONAL_ID"
          NATIONAL_ID_TYPE_CD length=$10 format=$10. label="NATIONAL_ID_TYPE_CD"
          UI_DEF_FILE_NM length=$100 format=$100. label="UI_DEF_FILE_NM"
          CREATE_USER_ID length=$60 format=$60. label="CREATE_USER_ID"
          CREATE_DTTM length=8 format=DATETIME27.6 label="CREATE_DTTM"
          UPDATE_USER_ID length=$60 format=$60. label="UPDATE_USER_ID"
          VERSION_NO length=8 format=11. label="VERSION_NO"
          DELETE_FLG length=$1 format=$1. label="DELETE_FLG"
          PARTY_TAX_ID length=$35 format=$35. label="PARTY_TAX_ID"
          RISK_CLASSIFICATION length=8 format=2. label="RISK_CLASSIFICATION"
          PARTY_key length=8 format=BEST32. label="PARTY_KEY"
          OLD_VALID_FROM_DTTM length=8 format=DATETIME27.6 label="OLD_VALID_FROM_DTTM"
          ; 
   
   retain missing0-missing0 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table ecm_db.PARTY_LIVE */ 
      nlobs = .; 
      dsid = open("ecm_db.PARTY_LIVE"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "ecm_db.PARTY_LIVE", hashexp: exponent);
            h0.defineKey( "PARTY_ID");
            h0.defineData( "PARTY_RK",
                           "SOURCE_SYSTEM_CD",
                           "PARTY_TYPE_CD",
                           "PARTY_CATEGORY_CD",
                           "PARTY_SUBCATEGORY_CD",
                           "IDENTICAL_PARTY_LINK_SK",
                           "INDIVIDUAL_FLG",
                           "NATIONAL_ID",
                           "NATIONAL_ID_TYPE_CD",
                           "UI_DEF_FILE_NM",
                           "CREATE_USER_ID",
                           "CREATE_DTTM",
                           "UPDATE_USER_ID",
                           "DELETE_FLG",
                           "VERSION_NO",
                           "VALID_TO_DTTM",
                           "VALID_FROM_DTTM");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: ecm_db.PARTY_LIVE";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " ecm_db.PARTY_LIVE";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: ecm_db.PARTY_LIVE";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " ecm_db.PARTY_LIVE";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " ecm_db.PARTY_LIVE";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " ecm_db.PARTY_LIVE";
         
         abort 3; 
      end; 
      
      call missing (PARTY_ID, PARTY_RK, SOURCE_SYSTEM_CD, PARTY_TYPE_CD, 
                    PARTY_CATEGORY_CD, PARTY_SUBCATEGORY_CD, IDENTICAL_PARTY_LINK_SK, 
                    INDIVIDUAL_FLG, NATIONAL_ID, NATIONAL_ID_TYPE_CD, UI_DEF_FILE_NM, 
                    CREATE_USER_ID, CREATE_DTTM, UPDATE_USER_ID, DELETE_FLG, 
                    VERSION_NO, VALID_TO_DTTM, VALID_FROM_DTTM); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W227S7ML end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: PARTY_ID);
   OLD_VALID_FROM_DTTM = VALID_FROM_DTTM;
   /* Examine success of lookups  */ 
   if ( rc0=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W8PULUU3; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Abort  */ 
         abort 4; 
      end; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

data _null_;
  call symput('current_dt',put(datetime(),datetime22.));
run;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2288GWR;
quit;

proc sql;
   create table work.W2288GWR as
      select
         PARTY_RK,
         ("&current_dt"dt) as VALID_FROM_DTTM length = 8
            format = DATETIME27.6
            informat = DATETIME27.6
            label = 'VALID_FROM_DTTM',
         VALID_TO_DTTM,
         PARTY_ID,
         SOURCE_SYSTEM_CD,
         PARTY_TYPE_CD,
         PARTY_CATEGORY_CD,
         PARTY_SUBCATEGORY_CD,
         IDENTICAL_PARTY_LINK_SK,
         INDIVIDUAL_FLG,
         PARTY_FULL_NM,
         NATIONAL_ID,
         NATIONAL_ID_TYPE_CD,
         UI_DEF_FILE_NM,
         CREATE_USER_ID,
         CREATE_DTTM,
         UPDATE_USER_ID,
         VERSION_NO,
         DELETE_FLG,
         PARTY_TAX_ID,
         RISK_CLASSIFICATION,
         PARTY_key,
         OLD_VALID_FROM_DTTM
   from work.W8PULUU3
   ;
quit;

%let SOURCEDS = work.W2288GWR;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8PULUU3;
quit;


/*==========================================================================* 
 * Step:            Update                                A5DG55RP.BV0002XS * 
 * Transform:       Update                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VW * 
 * Target Table:    PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 *                                                                          * 
 * User Written:    SourceCode                                              * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc sql;
   update ecm_db.PARTY_LIVE
      set 
         VALID_FROM_DTTM= (
            select
               W2288GWR.VALID_FROM_DTTM length = 8   
                  format = DATETIME27.6
                  informat = DATETIME27.6
                  label = 'VALID_FROM_DTTM'
            from
               work.W2288GWR as W2288GWR
            where
               PARTY_LIVE.PARTY_RK = W2288GWR.PARTY_RK
         ),
         VERSION_NO= VERSION_NO + 1
      where
         PARTY_RK IN (
            select
               W2288GWR.PARTY_RK length = 8   
                  format = 11.
                  informat = 11.
                  label = 'PARTY_RK'
            from
               work.W2288GWR as W2288GWR
         )
   ;
quit;

/*==========================================================================* 
 * Step:            Update                                A5DG55RP.BV0002XT * 
 * Transform:       Update                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VW * 
 * Target Table:    PARTY_VERSION - ecm_db.PARTY_VERSION  A5DG55RP.BH00019Z * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc sql;
   update ecm_db.PARTY_VERSION
      set 
         VALID_TO_DTTM= (
            select
               W2288GWR.VALID_FROM_DTTM length = 8   
                  format = DATETIME27.6
                  informat = DATETIME27.6
                  label = 'VALID_FROM_DTTM'
            from
               work.W2288GWR as W2288GWR
            where
               PARTY_VERSION.PARTY_RK = W2288GWR.PARTY_RK
         )
      where
         VALID_TO_DTTM = .
         and PARTY_RK IN (
            select
               W2288GWR.PARTY_RK length = 8   
                  format = 11.
                  informat = 11.
                  label = 'PARTY_RK'
            from
               work.W2288GWR as W2288GWR
         )
   ;
quit;

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002XU * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VW * 
 * Target Table:    PARTY_VERSION - ecm_db.PARTY_VERSION  A5DG55RP.BH00019Z * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc datasets lib = work nolist nowarn memtype = (data view);
      delete W8PULVJ6;
quit;

proc sql;
  create view work.W8PULVJ6 as
     select
        PARTY_RK,
        VALID_FROM_DTTM,
        VALID_TO_DTTM,
        PARTY_ID,
        SOURCE_SYSTEM_CD,
        PARTY_TYPE_CD,
        PARTY_CATEGORY_CD,
        PARTY_SUBCATEGORY_CD,
        IDENTICAL_PARTY_LINK_SK,
        INDIVIDUAL_FLG,
        PARTY_FULL_NM length = 100   
           format = $100.
           informat = $100.,
        NATIONAL_ID,
        NATIONAL_ID_TYPE_CD,
        UI_DEF_FILE_NM,
        CREATE_USER_ID,
        CREATE_DTTM,
        UPDATE_USER_ID,
        (VERSION_NO+1) as VERSION_NO length = 8
           format = 11.
           informat = 11.,
        DELETE_FLG
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W8PULVJ6;

proc append base = ecm_db.PARTY_VERSION 
  data = &SOURCEDS force ; 
run; 

proc datasets lib = work nolist nowarn memtype = (data view);
  delete W8PULVJ6;
quit;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002XV * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VW * 
 * Target Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc datasets lib = work nolist nowarn memtype = (data view);
  delete W8PZAEFL;
quit;

proc sql;
  create view work.W8PZAEFL as
     select
        . as EVENT_RK length = 8
           format = 11.
           informat = 11.,
        ("PARTY") as BUSINESS_OBJECT_NM length = 100
           format = $100.
           informat = $100.,
        PARTY_RK as BUSINESS_OBJECT_RK,
        ("SAVENT") as EVENT_TYPE_CD length = 10
           format = $10.
           informat = $10.,
        "" as EVENT_DESC length = 256
           format = $256.
           informat = $256.,
        CREATE_USER_ID,
        VALID_FROM_DTTM as CREATE_DTTM,
        "" as LINKED_OBJECT_NM length = 100
           format = $100.
           informat = $100.,
        . as LINKED_OBJECT_RK length = 8
           format = 11.
           informat = 11.
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W8PZAEFL;

proc datasets lib = iem nolist nowarn memtype = (data view);
  delete new_events;
quit;
  
data iem.new_events;
  attrib EVENT_RK length = 8
     format = 11.
     informat = 11.
     label = 'EVENT_RK'; 
  attrib BUSINESS_OBJECT_NM length = $100
     format = $100.
     informat = $100.
     label = 'BUSINESS_OBJECT_NM'; 
  attrib BUSINESS_OBJECT_RK length = 8
     format = 11.
     informat = 11.
     label = 'BUSINESS_OBJECT_RK'; 
  attrib EVENT_TYPE_CD length = $10
     format = $10.
     informat = $10.
     label = 'EVENT_TYPE_CD'; 
  attrib EVENT_DESC length = $256
     format = $256.
     informat = $256.
     label = 'EVENT_DESC'; 
  attrib CREATE_USER_ID length = $60
     format = $60.
     informat = $60.
     label = 'CREATE_USER_ID'; 
  attrib CREATE_DTTM length = 8
     format = DATETIME27.6
     informat = DATETIME27.6
     label = 'CREATE_DTTM'; 
  attrib LINKED_OBJECT_NM length = $100
     format = $100.
     informat = $100.
     label = 'LINKED_OBJECT_NM'; 
  attrib LINKED_OBJECT_RK length = 8
     format = 11.
     informat = 11.
     label = 'LINKED_OBJECT_RK'; 
  call missing(of _all_);
  stop;
run;
   
proc append base = iem.new_events 
   data = &SOURCEDS force ; 
run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8PZAEFL;
quit;


%let obs_count = %fcf_get_observation_count(table=iem.new_events, SASDATASET=Y);
%let numevents = &obs_count;

%fcf_get_ecm_sequence_ids(numIDs=&numevents, ecmSeq=event);

data iem.new_events;
	set iem.new_events;
	event_rk = symgetn('seqId'||(kstrip(put(_n_,best32.))));
run;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002XW * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 * Target Table:    ECM_EVENT - ecm_db.ECM_EVENT          A5DG55RP.BH00019J * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.new_events); 
   
proc append base = ecm_db.ECM_EVENT 
  data = &SOURCEDS force ; 
run; 

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002XX * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VW * 
 * Target Table:    Extract - work.WH0NTV3S               A5DG55RP.BR0001VY * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete WH0NTV3S;
quit;

proc sql;
   create view work.WH0NTV3S as
      select
         PARTY_RK,
         VALID_FROM_DTTM,
         PARTY_TAX_ID as X_SASFCS_TIN
   from &SOURCEDS
   ;
quit;

%let SOURCEDS = work.WH0NTV3S;

/*==========================================================================* 
 * Step:            Sort                                  A5DG55RP.BV00034O * 
 * Transform:       Sort                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Extract - work.WH0NTV3S               A5DG55RP.BR0001VY * 
 * Target Table:    Sort - work.W8FPW6HX                  A5DG55RP.BR000205 * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.WH0NTV3S); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8FPW6HX;
quit;

proc sort data = &SOURCEDS 
   out = work.W8FPW6HX; 
   by
      PARTY_RK
      VALID_FROM_DTTM
   ;
run; 

/*==========================================================================* 
 * Step:            Transpose                             A5DG55RP.BV0002XY * 
 * Transform:       Transpose                                               * 
 * Description:     Creates an output table by restructuring the values in  * 
 *                  the source table, transposing selected columns into     * 
 *                   rows.                                                  * 
 *                                                                          * 
 * Source Table:    Sort - work.W8FPW6HX                  A5DG55RP.BR000205 * 
 * Target Table:    Subject Character UDF Fields -        A5DG55RP.BH0001AZ * 
 *                   iem.Subject_Character_Udf_Fields                       * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W8FPW6HX); 

%let _INPUT = work.W8FPW6HX;
%let _INPUT_options = %nrquote();

%let _OUTPUT = iem.Subject_Character_Udf_Fields;
%let _OUTPUT_options = %nrquote();

proc datasets lib=iem nolist nowarn memtype = (data view);
   delete Subject_Character_Udf_Fields;
quit;

%let varColumns = X_SASFCS_TIN;
%let byColumns = PARTY_RK VALID_FROM_DTTM;

options mprint;

proc transpose data = &_INPUT (&_INPUT_options) out = &_OUTPUT (&_OUTPUT_options);
  by &byColumns;
  var &varColumns;
run;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002XZ * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Subject Character UDF Fields -        A5DG55RP.BH0001AZ * 
 *                   iem.Subject_Character_Udf_Fields                       * 
 * Target Table:    New Character UDFs -                  A5DG55RP.BH0001AT * 
 *                   iem.New_Character_UDFs                                 * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.Subject_Character_Udf_Fields); 

proc datasets lib = work nolist nowarn memtype = (data view);
  delete W8PULWKF;
quit;

proc sql;
  create view work.W8PULWKF as
     select
        PARTY_RK   
           format = 11.
           informat = 11.,
        VALID_FROM_DTTM,
        ('PARTY') as UDF_TABLE_NM length = 30
           format = $30.
           informat = $30.,
        _NAME_ as UDF_NM   
           format = $30.
           informat = $30.,
        (1) as ROW_NO length = 8
           format = 11.
           informat = 11.,
        COL1 as UDF_VALUE length = 4000   
           format = $4000.
           informat = $4000.
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W8PULWKF;

proc datasets lib = iem nolist nowarn memtype = (data view);
  delete New_Character_UDFs;
quit;

data iem.New_Character_UDFs;
  attrib PARTY_RK length = 8
     format = 11.
     informat = 11.
     label = 'PARTY_RK'; 
  attrib VALID_FROM_DTTM length = 8
     format = DATETIME27.6
     informat = DATETIME27.6
     label = 'VALID_FROM_DTTM'; 
  attrib UDF_TABLE_NM length = $30
     format = $30.
     informat = $30.
     label = 'UDF_TABLE_NM'; 
  attrib UDF_NM length = $30
     format = $30.
     informat = $30.
     label = 'UDF_NM'; 
  attrib ROW_NO length = 8
     format = 11.
     informat = 11.
     label = 'ROW_NO'; 
  attrib UDF_VALUE length = $4000
     format = $4000.
     informat = $4000.
     label = 'UDF_VALUE'; 
  call missing(of _all_);
  stop;
run;
   
proc append base = iem.New_Character_UDFs 
   data = &SOURCEDS force ; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8PULWKF;
quit;

/*==========================================================================* 
 * Step:            Join                                  A5DG55RP.BV00033H * 
 * Transform:       Join                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W2288GWR                A5DG55RP.BR0001VW * 
 *                  PARTY_UDF_CHAR_VALUE -                A5DG55RP.BH00019X * 
 *                   ecm_db.PARTY_UDF_CHAR_VALUE                            * 
 * Target Table:    Join - work.W53G8ST1                  A5DG55RP.BR0001ZI * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W53G8ST1;
quit;

proc sql;
   create view work.W53G8ST1 as
   select
      PARTY_UDF_CHAR_VALUE.PARTY_RK length = 8   
         format = 11.
         informat = 11.
         label = 'PARTY_RK',
      W2288GWR.VALID_FROM_DTTM length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_FROM_DTTM',
      PARTY_UDF_CHAR_VALUE.UDF_TABLE_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_TABLE_NM',
      PARTY_UDF_CHAR_VALUE.UDF_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_NM',
      PARTY_UDF_CHAR_VALUE.ROW_NO length = 8   
         format = 11.
         informat = 11.
         label = 'ROW_NO',
      PARTY_UDF_CHAR_VALUE.UDF_VALUE length = 4000   
         format = $4000.
         informat = $4000.
         label = 'UDF_VALUE'
   from
      work.W2288GWR, 
      ecm_db.PARTY_UDF_CHAR_VALUE
   where
      W2288GWR.PARTY_RK = PARTY_UDF_CHAR_VALUE.PARTY_RK
      and W2288GWR.OLD_VALID_FROM_DTTM = PARTY_UDF_CHAR_VALUE.VALID_FROM_DTTM
      and PARTY_UDF_CHAR_VALUE.UDF_NM NOT IN ('X_SASFCS_TIN')
   ;
quit;

/*==========================================================================* 
 * Step:            Append                                A5DG55RP.BV00033I * 
 * Transform:       Append                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Join - work.W53G8ST1                  A5DG55RP.BR0001ZI * 
 *                  New Character UDFs -                  A5DG55RP.BH0001AT * 
 *                   iem.New_Character_UDFs                                 * 
 * Target Table:    Append - work.W53U8GKZ                A5DG55RP.BR0001ZJ * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W53U8GKZ;
quit;

data work.W53U8GKZ / view=work.W53U8GKZ;
   set work.W53G8ST1
       iem.New_Character_UDFs;
   keep PARTY_RK VALID_FROM_DTTM UDF_TABLE_NM UDF_NM ROW_NO UDF_VALUE; 
run;

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV00033J * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Append - work.W53U8GKZ                A5DG55RP.BR0001ZJ * 
 * Target Table:    PARTY_UDF_CHAR_VALUE -                A5DG55RP.BH00019X * 
 *                   ecm_db.PARTY_UDF_CHAR_VALUE                            * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W53U8GKZ); 
   
proc append base = ecm_db.PARTY_UDF_CHAR_VALUE 
  data = &SOURCEDS force ; 
run; 
   
/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002XP * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VW * 
 * Target Table:    Extract - work.W7JA203I               A5DG55RP.BR0001VX * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W7JA203I;
quit;

proc sql;
   create view work.W7JA203I as
      select
         PARTY_RK,
         VALID_FROM_DTTM,
         RISK_CLASSIFICATION as X_SASFCS_RSK_CLSSF,
         PARTY_key as X_SASFCS_PTY_KEY
   from &SOURCEDS
   ;
quit;

%let SOURCEDS = work.W7JA203I;

/*==========================================================================* 
 * Step:            Sort                                  A5DG55RP.BV00034P * 
 * Transform:       Sort                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Extract - work.W7JA203I               A5DG55RP.BR0001VX * 
 * Target Table:    Sort - work.W8FQWVMV                  A5DG55RP.BR000206 * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8FQWVMV;
quit;

proc sort data = &SOURCEDS 
   out = work.W8FQWVMV; 
   by
      PARTY_RK
      VALID_FROM_DTTM
   ;
run; 

/*==========================================================================* 
 * Step:            Transpose                             A5DG55RP.BV0002XQ * 
 * Transform:       Transpose                                               * 
 * Description:     Creates an output table by restructuring the values in  * 
 *                  the source table, transposing selected columns into     * 
 *                   rows.                                                  * 
 *                                                                          * 
 * Source Table:    Sort - work.W8FQWVMV                  A5DG55RP.BR000206 * 
 * Target Table:    Subject Numeric UDF Fields -          A5DG55RP.BH0001B0 * 
 *                   iem.Subject_Numeric_Udf_Fields                         * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W8FQWVMV); 

%let _INPUT = work.W8FQWVMV;
%let _INPUT_options = %nrquote();

%let _OUTPUT = iem.Subject_Numeric_Udf_Fields;
%let _OUTPUT_options = %nrquote();

proc datasets lib=iem nolist nowarn memtype = (data view);
   delete Subject_Numeric_Udf_Fields;
quit;

%let varColumns = X_SASFCS_RSK_CLSSF X_SASFCS_PTY_KEY;
%let byColumns = PARTY_RK VALID_FROM_DTTM;

proc transpose data = &_INPUT (&_INPUT_options) out = &_OUTPUT (&_OUTPUT_options);
	by &byColumns;
	var &varColumns;
run;

/*==========================================================================* 
 * Step:            Data Validation                       A5DG55RP.BV00032F * 
 * Transform:       Data Validation                                         * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Subject Numeric UDF Fields -          A5DG55RP.BH0001B0 * 
 *                   iem.Subject_Numeric_Udf_Fields                         * 
 * Target Table:    Data Validation - work.WAKSDUUO       A5DG55RP.BR0001YW * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.Subject_Numeric_Udf_Fields); 
   
proc datasets lib = work nolist nowarn memtype = (data view);
	delete WAKSDUUO;
quit;

%let m_excp = 0;

/*---- Begin checks for Custom, Missing Values, and Invalid Values  ----*/ 
data work.WAKSDUUO
	 (keep = PARTY_RK VALID_FROM_DTTM _NAME_ _LABEL_ COL1)
	work.etls_Errors
	 (keep = PARTY_RK VALID_FROM_DTTM _NAME_ _LABEL_ COL1);

	set &SOURCEDS;

	i_move = 0;

	/*---- Custom Validation: New Custom Validation  ----*/ 
	if (_NAME_ = "X_SASFCS_RSK_CLSSF"  & COL1 = .) then 
	do; 
	 i_move = 1; 
	end;  /* if (_NAME_ = "X_SASFCS_RSK_CLSSF"  & COL1 = .) */

	/* move record to error file  */ 
	if (i_move) then 
	 output work.etls_Errors;
	/* move record to output file  */ 
	else 
	 output work.WAKSDUUO;
run;
     
proc datasets lib = work nolist nowarn memtype = (data view);
  	delete etls_Errors;
quit;
   

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002XR * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    work.WAKSDUUO				          A5DG55RP.BH0001B0 *
 * Target Table:    New Numeric UDFs -                    A5DG55RP.BH0001BK * 
 *                   iem.New_Numeric_UDFs                                   * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.WAKSDUUO); 

proc datasets lib = work nolist nowarn memtype = (data view);
  delete W8PULXH7;
quit;

proc sql;
  create view work.W8PULXH7 as
     select
        PARTY_RK,
        VALID_FROM_DTTM,
        ('PARTY') as UDF_TABLE_NM length = 30
           format = $30.
           informat = $30.,
        _NAME_ as UDF_NM length = 30   
           format = $30.
           informat = $30.,
        (1) as ROW_NO length = 8
           format = 11.
           informat = 11.,
        COL1 as UDF_VALUE
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W8PULXH7;

proc datasets lib = iem nolist nowarn memtype = (data view);
  delete New_Numeric_UDFs;
quit;

data iem.New_Numeric_UDFs;
  attrib PARTY_RK length = 8
     format = 11.
     informat = 11.
     label = 'PARTY_RK'; 
  attrib VALID_FROM_DTTM length = 8
     format = DATETIME27.6
     informat = DATETIME27.6
     label = 'VALID_FROM_DTTM'; 
  attrib UDF_TABLE_NM length = $30
     format = $30.
     informat = $30.
     label = 'UDF_TABLE_NM'; 
  attrib UDF_NM length = $30
     format = $30.
     informat = $30.
     label = 'UDF_NM'; 
  attrib ROW_NO length = 8
     format = 11.
     informat = 11.
     label = 'ROW_NO'; 
  attrib UDF_VALUE length = 8
     label = 'UDF_VALUE'; 
  call missing(of _all_);
  stop;
run;
   
proc append base = iem.New_Numeric_UDFs 
   data = &SOURCEDS force ; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8PULXH7;
quit;

/*==========================================================================* 
 * Step:            Join                                  A5DG55RP.BV00033K * 
 * Transform:       Join                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W2288GWR                A5DG55RP.BR0001VW * 
 *                  PARTY_UDF_NUM_VALUE -                 A5DG55RP.BH00019Y * 
 *                   ecm_db.PARTY_UDF_NUM_VALUE                             * 
 * Target Table:    Join - work.W5ITWMDJ                  A5DG55RP.BR0001ZK * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5ITWMDJ;
quit;

proc sql;
   create view work.W5ITWMDJ as
   select
      PARTY_UDF_NUM_VALUE.PARTY_RK length = 8   
         format = 11.
         informat = 11.
         label = 'PARTY_RK',
      W2288GWR.VALID_FROM_DTTM length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_FROM_DTTM',
      PARTY_UDF_NUM_VALUE.UDF_TABLE_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_TABLE_NM',
      PARTY_UDF_NUM_VALUE.UDF_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_NM',
      PARTY_UDF_NUM_VALUE.ROW_NO length = 8   
         format = 11.
         informat = 11.
         label = 'ROW_NO',
      PARTY_UDF_NUM_VALUE.UDF_VALUE length = 8   
         label = 'UDF_VALUE'
   from
      work.W2288GWR, 
      ecm_db.PARTY_UDF_NUM_VALUE
   where
      W2288GWR.PARTY_RK = PARTY_UDF_NUM_VALUE.PARTY_RK
      and W2288GWR.OLD_VALID_FROM_DTTM = PARTY_UDF_NUM_VALUE.VALID_FROM_DTTM
      and PARTY_UDF_NUM_VALUE.UDF_NM NOT IN ('X_SASFCS_RSK_CLSSF','X_SASFCS_PTY_KEY')
   ;
quit;

/*==========================================================================* 
 * Step:            Append                                A5DG55RP.BV00033N * 
 * Transform:       Append                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Join - work.W5ITWMDJ                  A5DG55RP.BR0001ZK * 
 *                  New Numeric UDFs -                    A5DG55RP.BH0001BK * 
 *                   iem.New_Numeric_UDFs                                   * 
 * Target Table:    Append - work.W74NCLVN                A5DG55RP.BR0001ZN * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W74NCLVN;
quit;

data work.W74NCLVN / view=work.W74NCLVN;
   set work.W5ITWMDJ
       iem.New_Numeric_UDFs;
   keep PARTY_RK VALID_FROM_DTTM UDF_TABLE_NM UDF_NM ROW_NO UDF_VALUE; 
run;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV00033O * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Append - work.W74NCLVN                A5DG55RP.BR0001ZN * 
 * Target Table:    PARTY_UDF_NUM_VALUE -                 A5DG55RP.BH00019Y * 
 *                   ecm_db.PARTY_UDF_NUM_VALUE                             * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W74NCLVN); 
   
proc append base = ecm_db.PARTY_UDF_NUM_VALUE 
  data = &SOURCEDS force ; 
run; 

/*==========================================================================* 
 * Step:            Join                                  A5DG55RP.BV00033L * 
 * Transform:       Join                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W2288GWR                A5DG55RP.BR0001VW * 
 *                  PARTY_UDF_LGCHR_VALUE -               A5DG55RP.BH0001BN * 
 *                   ecm_db.PARTY_UDF_LGCHR_VALUE                           * 
 * Target Table:    Join - work.W5J1BDQM                  A5DG55RP.BR0001ZL * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5J1BDQM;
quit;

proc sql;
   create table work.W5J1BDQM as
   select
      PARTY_UDF_LGCHR_VALUE.PARTY_RK length = 8   
         format = 11.
         informat = 11.
         label = 'PARTY_RK',
      W2288GWR.VALID_FROM_DTTM length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_FROM_DTTM',
      PARTY_UDF_LGCHR_VALUE.UDF_TABLE_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_TABLE_NM',
      PARTY_UDF_LGCHR_VALUE.UDF_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_NM',
      PARTY_UDF_LGCHR_VALUE.ROW_NO length = 8   
         format = 11.
         informat = 11.
         label = 'ROW_NO',
      PARTY_UDF_LGCHR_VALUE.UDF_VALUE length = 1024   
         format = $1024.
         informat = $1024.
         label = 'UDF_VALUE'
   from
      work.W2288GWR, 
      ecm_db.PARTY_UDF_LGCHR_VALUE
   where
      W2288GWR.OLD_VALID_FROM_DTTM = PARTY_UDF_LGCHR_VALUE.VALID_FROM_DTTM
      and W2288GWR.PARTY_RK = PARTY_UDF_LGCHR_VALUE.PARTY_RK
   ;
quit;

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV00033P * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Join - work.W5J1BDQM                  A5DG55RP.BR0001ZL * 
 * Target Table:    PARTY_UDF_LGCHR_VALUE -               A5DG55RP.BH0001BN * 
 *                   ecm_db.PARTY_UDF_LGCHR_VALUE                           * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W5J1BDQM); 
   
proc append base = ecm_db.PARTY_UDF_LGCHR_VALUE 
  data = &SOURCEDS force ; 
run; 

/*==========================================================================* 
 * Step:            Join                                  A5DG55RP.BV00033M * 
 * Transform:       Join                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W2288GWR                A5DG55RP.BR0001VW * 
 *                  PARTY_UDF_DATE_VALUE -                A5DG55RP.BH0001BL * 
 *                   ecm_db.PARTY_UDF_DATE_VALUE                            * 
 * Target Table:    Join - work.W5J1C3JU                  A5DG55RP.BR0001ZM * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5J1C3JU;
quit;

proc sql;
   create table work.W5J1C3JU as
   select
      PARTY_UDF_DATE_VALUE.PARTY_RK length = 8   
         format = 11.
         informat = 11.
         label = 'PARTY_RK',
      W2288GWR.VALID_FROM_DTTM length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_FROM_DTTM',
      PARTY_UDF_DATE_VALUE.UDF_TABLE_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_TABLE_NM',
      PARTY_UDF_DATE_VALUE.UDF_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_NM',
      PARTY_UDF_DATE_VALUE.ROW_NO length = 8   
         format = 11.
         informat = 11.
         label = 'ROW_NO',
      PARTY_UDF_DATE_VALUE.UDF_VALUE length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'UDF_VALUE'
   from
      work.W2288GWR, 
      ecm_db.PARTY_UDF_DATE_VALUE
   where
      W2288GWR.PARTY_RK = PARTY_UDF_DATE_VALUE.PARTY_RK
      and W2288GWR.OLD_VALID_FROM_DTTM = PARTY_UDF_DATE_VALUE.VALID_FROM_DTTM
   ;
quit;

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV00033Q * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Join - work.W5J1C3JU                  A5DG55RP.BR0001ZM * 
 * Target Table:    PARTY_UDF_DATE_VALUE -                A5DG55RP.BH0001BL * 
 *                   ecm_db.PARTY_UDF_DATE_VALUE                            * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W5J1C3JU); 

proc append base = ecm_db.PARTY_UDF_DATE_VALUE 
  data = &SOURCEDS force ; 
run; 

%mend;
